diff --git a/app/assets/stylesheets/ForceDirected.css b/app/assets/stylesheets/ForceDirected.css
deleted file mode 100644
index d0fd0f50..00000000
--- a/app/assets/stylesheets/ForceDirected.css
+++ /dev/null
@@ -1,23 +0,0 @@
-#inner-details {
-
-}
-
-.label {
- display:block;
- white-space: nowrap;
- padding: 2px 4px;
- background:#ddd;
- opacity:0.8;
- border-radius:5px;
-}
-
-span.name {
- cursor: pointer;
- position: absolute;
- -webkit-touch-callout: none;
- -webkit-user-select: none;
- -khtml-user-select: none;
- -moz-user-select: none;
- -ms-user-select: none;
- user-select: none;
-}
diff --git a/app/assets/stylesheets/users.css.scss b/app/assets/stylesheets/admin.css
similarity index 81%
rename from app/assets/stylesheets/users.css.scss
rename to app/assets/stylesheets/admin.css
index 829f76f8..70e68127 100644
--- a/app/assets/stylesheets/users.css.scss
+++ b/app/assets/stylesheets/admin.css
@@ -1,6 +1,3 @@
-// Place all the styles related to the users controller here.
-// They will automatically be included in application.css.
-// You can use Sass (SCSS) here: http://sass-lang.com/
.allMetacodes {
diff --git a/app/assets/stylesheets/animate.css b/app/assets/stylesheets/animate.css
deleted file mode 100644
index 274c303e..00000000
--- a/app/assets/stylesheets/animate.css
+++ /dev/null
@@ -1,3263 +0,0 @@
-@charset "UTF-8";
-/*
-Animate.css - http://daneden.me/animate
-Licensed under the ☺ license (http://licence.visualidiot.com/)
-
-Copyright (c) 2012 Dan Eden
-
-Permission is hereby granted, free of charge, to any person obtaining a copy of this software and associated documentation files (the "Software"), to deal in the Software without restriction, including without limitation the rights to use, copy, modify, merge, publish, distribute, sublicense, and/or sell copies of the Software, and to permit persons to whom the Software is furnished to do so, subject to the following conditions:
-
-The above copyright notice and this permission notice shall be included in all copies or substantial portions of the Software.
-
-THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY, FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM, OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE SOFTWARE.
-*/
-body { /* Addresses a small issue in webkit: http://bit.ly/NEdoDq */
- -webkit-backface-visibility: hidden;
-}
-.animated {
- -webkit-animation-duration: 1s;
- -moz-animation-duration: 1s;
- -o-animation-duration: 1s;
- animation-duration: 1s;
- -webkit-animation-fill-mode: both;
- -moz-animation-fill-mode: both;
- -o-animation-fill-mode: both;
- animation-fill-mode: both;
-}
-
-.animated.hinge {
- -webkit-animation-duration: 2s;
- -moz-animation-duration: 2s;
- -o-animation-duration: 2s;
- animation-duration: 2s;
-}
-
-@-webkit-keyframes flash {
- 0%, 50%, 100% {opacity: 1;}
- 25%, 75% {opacity: 0;}
-}
-
-@-moz-keyframes flash {
- 0%, 50%, 100% {opacity: 1;}
- 25%, 75% {opacity: 0;}
-}
-
-@-o-keyframes flash {
- 0%, 50%, 100% {opacity: 1;}
- 25%, 75% {opacity: 0;}
-}
-
-@keyframes flash {
- 0%, 50%, 100% {opacity: 1;}
- 25%, 75% {opacity: 0;}
-}
-
-.flash {
- -webkit-animation-name: flash;
- -moz-animation-name: flash;
- -o-animation-name: flash;
- animation-name: flash;
-}
-@-webkit-keyframes shake {
- 0%, 100% {-webkit-transform: translateX(0);}
- 10%, 30%, 50%, 70%, 90% {-webkit-transform: translateX(-10px);}
- 20%, 40%, 60%, 80% {-webkit-transform: translateX(10px);}
-}
-
-@-moz-keyframes shake {
- 0%, 100% {-moz-transform: translateX(0);}
- 10%, 30%, 50%, 70%, 90% {-moz-transform: translateX(-10px);}
- 20%, 40%, 60%, 80% {-moz-transform: translateX(10px);}
-}
-
-@-o-keyframes shake {
- 0%, 100% {-o-transform: translateX(0);}
- 10%, 30%, 50%, 70%, 90% {-o-transform: translateX(-10px);}
- 20%, 40%, 60%, 80% {-o-transform: translateX(10px);}
-}
-
-@keyframes shake {
- 0%, 100% {transform: translateX(0);}
- 10%, 30%, 50%, 70%, 90% {transform: translateX(-10px);}
- 20%, 40%, 60%, 80% {transform: translateX(10px);}
-}
-
-.shake {
- -webkit-animation-name: shake;
- -moz-animation-name: shake;
- -o-animation-name: shake;
- animation-name: shake;
-}
-@-webkit-keyframes bounce {
- 0%, 20%, 50%, 80%, 100% {-webkit-transform: translateY(0);}
- 40% {-webkit-transform: translateY(-30px);}
- 60% {-webkit-transform: translateY(-15px);}
-}
-
-@-moz-keyframes bounce {
- 0%, 20%, 50%, 80%, 100% {-moz-transform: translateY(0);}
- 40% {-moz-transform: translateY(-30px);}
- 60% {-moz-transform: translateY(-15px);}
-}
-
-@-o-keyframes bounce {
- 0%, 20%, 50%, 80%, 100% {-o-transform: translateY(0);}
- 40% {-o-transform: translateY(-30px);}
- 60% {-o-transform: translateY(-15px);}
-}
-@keyframes bounce {
- 0%, 20%, 50%, 80%, 100% {transform: translateY(0);}
- 40% {transform: translateY(-30px);}
- 60% {transform: translateY(-15px);}
-}
-
-.bounce {
- -webkit-animation-name: bounce;
- -moz-animation-name: bounce;
- -o-animation-name: bounce;
- animation-name: bounce;
-}
-@-webkit-keyframes tada {
- 0% {-webkit-transform: scale(1);}
- 10%, 20% {-webkit-transform: scale(0.9) rotate(-3deg);}
- 30%, 50%, 70%, 90% {-webkit-transform: scale(1.1) rotate(3deg);}
- 40%, 60%, 80% {-webkit-transform: scale(1.1) rotate(-3deg);}
- 100% {-webkit-transform: scale(1) rotate(0);}
-}
-
-@-moz-keyframes tada {
- 0% {-moz-transform: scale(1);}
- 10%, 20% {-moz-transform: scale(0.9) rotate(-3deg);}
- 30%, 50%, 70%, 90% {-moz-transform: scale(1.1) rotate(3deg);}
- 40%, 60%, 80% {-moz-transform: scale(1.1) rotate(-3deg);}
- 100% {-moz-transform: scale(1) rotate(0);}
-}
-
-@-o-keyframes tada {
- 0% {-o-transform: scale(1);}
- 10%, 20% {-o-transform: scale(0.9) rotate(-3deg);}
- 30%, 50%, 70%, 90% {-o-transform: scale(1.1) rotate(3deg);}
- 40%, 60%, 80% {-o-transform: scale(1.1) rotate(-3deg);}
- 100% {-o-transform: scale(1) rotate(0);}
-}
-
-@keyframes tada {
- 0% {transform: scale(1);}
- 10%, 20% {transform: scale(0.9) rotate(-3deg);}
- 30%, 50%, 70%, 90% {transform: scale(1.1) rotate(3deg);}
- 40%, 60%, 80% {transform: scale(1.1) rotate(-3deg);}
- 100% {transform: scale(1) rotate(0);}
-}
-
-.tada {
- -webkit-animation-name: tada;
- -moz-animation-name: tada;
- -o-animation-name: tada;
- animation-name: tada;
-}
-@-webkit-keyframes swing {
- 20%, 40%, 60%, 80%, 100% { -webkit-transform-origin: top center; }
- 20% { -webkit-transform: rotate(15deg); }
- 40% { -webkit-transform: rotate(-10deg); }
- 60% { -webkit-transform: rotate(5deg); }
- 80% { -webkit-transform: rotate(-5deg); }
- 100% { -webkit-transform: rotate(0deg); }
-}
-
-@-moz-keyframes swing {
- 20% { -moz-transform: rotate(15deg); }
- 40% { -moz-transform: rotate(-10deg); }
- 60% { -moz-transform: rotate(5deg); }
- 80% { -moz-transform: rotate(-5deg); }
- 100% { -moz-transform: rotate(0deg); }
-}
-
-@-o-keyframes swing {
- 20% { -o-transform: rotate(15deg); }
- 40% { -o-transform: rotate(-10deg); }
- 60% { -o-transform: rotate(5deg); }
- 80% { -o-transform: rotate(-5deg); }
- 100% { -o-transform: rotate(0deg); }
-}
-
-@keyframes swing {
- 20% { transform: rotate(15deg); }
- 40% { transform: rotate(-10deg); }
- 60% { transform: rotate(5deg); }
- 80% { transform: rotate(-5deg); }
- 100% { transform: rotate(0deg); }
-}
-
-.swing {
- -webkit-transform-origin: top center;
- -moz-transform-origin: top center;
- -o-transform-origin: top center;
- transform-origin: top center;
- -webkit-animation-name: swing;
- -moz-animation-name: swing;
- -o-animation-name: swing;
- animation-name: swing;
-}
-/* originally authored by Nick Pettit - https://github.com/nickpettit/glide */
-
-@-webkit-keyframes wobble {
- 0% { -webkit-transform: translateX(0%); }
- 15% { -webkit-transform: translateX(-25%) rotate(-5deg); }
- 30% { -webkit-transform: translateX(20%) rotate(3deg); }
- 45% { -webkit-transform: translateX(-15%) rotate(-3deg); }
- 60% { -webkit-transform: translateX(10%) rotate(2deg); }
- 75% { -webkit-transform: translateX(-5%) rotate(-1deg); }
- 100% { -webkit-transform: translateX(0%); }
-}
-
-@-moz-keyframes wobble {
- 0% { -moz-transform: translateX(0%); }
- 15% { -moz-transform: translateX(-25%) rotate(-5deg); }
- 30% { -moz-transform: translateX(20%) rotate(3deg); }
- 45% { -moz-transform: translateX(-15%) rotate(-3deg); }
- 60% { -moz-transform: translateX(10%) rotate(2deg); }
- 75% { -moz-transform: translateX(-5%) rotate(-1deg); }
- 100% { -moz-transform: translateX(0%); }
-}
-
-@-o-keyframes wobble {
- 0% { -o-transform: translateX(0%); }
- 15% { -o-transform: translateX(-25%) rotate(-5deg); }
- 30% { -o-transform: translateX(20%) rotate(3deg); }
- 45% { -o-transform: translateX(-15%) rotate(-3deg); }
- 60% { -o-transform: translateX(10%) rotate(2deg); }
- 75% { -o-transform: translateX(-5%) rotate(-1deg); }
- 100% { -o-transform: translateX(0%); }
-}
-
-@keyframes wobble {
- 0% { transform: translateX(0%); }
- 15% { transform: translateX(-25%) rotate(-5deg); }
- 30% { transform: translateX(20%) rotate(3deg); }
- 45% { transform: translateX(-15%) rotate(-3deg); }
- 60% { transform: translateX(10%) rotate(2deg); }
- 75% { transform: translateX(-5%) rotate(-1deg); }
- 100% { transform: translateX(0%); }
-}
-
-.wobble {
- -webkit-animation-name: wobble;
- -moz-animation-name: wobble;
- -o-animation-name: wobble;
- animation-name: wobble;
-}
-/* originally authored by Nick Pettit - https://github.com/nickpettit/glide */
-
-@-webkit-keyframes pulse {
- 0% { -webkit-transform: scale(1); }
- 50% { -webkit-transform: scale(1.1); }
- 100% { -webkit-transform: scale(1); }
-}
-@-moz-keyframes pulse {
- 0% { -moz-transform: scale(1); }
- 50% { -moz-transform: scale(1.1); }
- 100% { -moz-transform: scale(1); }
-}
-@-o-keyframes pulse {
- 0% { -o-transform: scale(1); }
- 50% { -o-transform: scale(1.1); }
- 100% { -o-transform: scale(1); }
-}
-@keyframes pulse {
- 0% { transform: scale(1); }
- 50% { transform: scale(1.1); }
- 100% { transform: scale(1); }
-}
-
-.pulse {
- -webkit-animation-name: pulse;
- -moz-animation-name: pulse;
- -o-animation-name: pulse;
- animation-name: pulse;
-}
-@-webkit-keyframes flip {
- 0% {
- -webkit-transform: perspective(400px) rotateY(0);
- -webkit-animation-timing-function: ease-out;
- }
- 40% {
- -webkit-transform: perspective(400px) translateZ(150px) rotateY(170deg);
- -webkit-animation-timing-function: ease-out;
- }
- 50% {
- -webkit-transform: perspective(400px) translateZ(150px) rotateY(190deg) scale(1);
- -webkit-animation-timing-function: ease-in;
- }
- 80% {
- -webkit-transform: perspective(400px) rotateY(360deg) scale(.95);
- -webkit-animation-timing-function: ease-in;
- }
- 100% {
- -webkit-transform: perspective(400px) scale(1);
- -webkit-animation-timing-function: ease-in;
- }
-}
-@-moz-keyframes flip {
- 0% {
- -moz-transform: perspective(400px) rotateY(0);
- -moz-animation-timing-function: ease-out;
- }
- 40% {
- -moz-transform: perspective(400px) translateZ(150px) rotateY(170deg);
- -moz-animation-timing-function: ease-out;
- }
- 50% {
- -moz-transform: perspective(400px) translateZ(150px) rotateY(190deg) scale(1);
- -moz-animation-timing-function: ease-in;
- }
- 80% {
- -moz-transform: perspective(400px) rotateY(360deg) scale(.95);
- -moz-animation-timing-function: ease-in;
- }
- 100% {
- -moz-transform: perspective(400px) scale(1);
- -moz-animation-timing-function: ease-in;
- }
-}
-@-o-keyframes flip {
- 0% {
- -o-transform: perspective(400px) rotateY(0);
- -o-animation-timing-function: ease-out;
- }
- 40% {
- -o-transform: perspective(400px) translateZ(150px) rotateY(170deg);
- -o-animation-timing-function: ease-out;
- }
- 50% {
- -o-transform: perspective(400px) translateZ(150px) rotateY(190deg) scale(1);
- -o-animation-timing-function: ease-in;
- }
- 80% {
- -o-transform: perspective(400px) rotateY(360deg) scale(.95);
- -o-animation-timing-function: ease-in;
- }
- 100% {
- -o-transform: perspective(400px) scale(1);
- -o-animation-timing-function: ease-in;
- }
-}
-@keyframes flip {
- 0% {
- transform: perspective(400px) rotateY(0);
- animation-timing-function: ease-out;
- }
- 40% {
- transform: perspective(400px) translateZ(150px) rotateY(170deg);
- animation-timing-function: ease-out;
- }
- 50% {
- transform: perspective(400px) translateZ(150px) rotateY(190deg) scale(1);
- animation-timing-function: ease-in;
- }
- 80% {
- transform: perspective(400px) rotateY(360deg) scale(.95);
- animation-timing-function: ease-in;
- }
- 100% {
- transform: perspective(400px) scale(1);
- animation-timing-function: ease-in;
- }
-}
-
-.flip {
- -webkit-backface-visibility: visible !important;
- -webkit-animation-name: flip;
- -moz-backface-visibility: visible !important;
- -moz-animation-name: flip;
- -o-backface-visibility: visible !important;
- -o-animation-name: flip;
- backface-visibility: visible !important;
- animation-name: flip;
-}
-@-webkit-keyframes flipInX {
- 0% {
- -webkit-transform: perspective(400px) rotateX(90deg);
- opacity: 0;
- }
-
- 40% {
- -webkit-transform: perspective(400px) rotateX(-10deg);
- }
-
- 70% {
- -webkit-transform: perspective(400px) rotateX(10deg);
- }
-
- 100% {
- -webkit-transform: perspective(400px) rotateX(0deg);
- opacity: 1;
- }
-}
-@-moz-keyframes flipInX {
- 0% {
- -moz-transform: perspective(400px) rotateX(90deg);
- opacity: 0;
- }
-
- 40% {
- -moz-transform: perspective(400px) rotateX(-10deg);
- }
-
- 70% {
- -moz-transform: perspective(400px) rotateX(10deg);
- }
-
- 100% {
- -moz-transform: perspective(400px) rotateX(0deg);
- opacity: 1;
- }
-}
-@-o-keyframes flipInX {
- 0% {
- -o-transform: perspective(400px) rotateX(90deg);
- opacity: 0;
- }
-
- 40% {
- -o-transform: perspective(400px) rotateX(-10deg);
- }
-
- 70% {
- -o-transform: perspective(400px) rotateX(10deg);
- }
-
- 100% {
- -o-transform: perspective(400px) rotateX(0deg);
- opacity: 1;
- }
-}
-@keyframes flipInX {
- 0% {
- transform: perspective(400px) rotateX(90deg);
- opacity: 0;
- }
-
- 40% {
- transform: perspective(400px) rotateX(-10deg);
- }
-
- 70% {
- transform: perspective(400px) rotateX(10deg);
- }
-
- 100% {
- transform: perspective(400px) rotateX(0deg);
- opacity: 1;
- }
-}
-
-.flipInX {
- -webkit-backface-visibility: visible !important;
- -webkit-animation-name: flipInX;
- -moz-backface-visibility: visible !important;
- -moz-animation-name: flipInX;
- -o-backface-visibility: visible !important;
- -o-animation-name: flipInX;
- backface-visibility: visible !important;
- animation-name: flipInX;
-}
-@-webkit-keyframes flipOutX {
- 0% {
- -webkit-transform: perspective(400px) rotateX(0deg);
- opacity: 1;
- }
- 100% {
- -webkit-transform: perspective(400px) rotateX(90deg);
- opacity: 0;
- }
-}
-
-@-moz-keyframes flipOutX {
- 0% {
- -moz-transform: perspective(400px) rotateX(0deg);
- opacity: 1;
- }
- 100% {
- -moz-transform: perspective(400px) rotateX(90deg);
- opacity: 0;
- }
-}
-
-@-o-keyframes flipOutX {
- 0% {
- -o-transform: perspective(400px) rotateX(0deg);
- opacity: 1;
- }
- 100% {
- -o-transform: perspective(400px) rotateX(90deg);
- opacity: 0;
- }
-}
-
-@keyframes flipOutX {
- 0% {
- transform: perspective(400px) rotateX(0deg);
- opacity: 1;
- }
- 100% {
- transform: perspective(400px) rotateX(90deg);
- opacity: 0;
- }
-}
-
-.flipOutX {
- -webkit-animation-name: flipOutX;
- -webkit-backface-visibility: visible !important;
- -moz-animation-name: flipOutX;
- -moz-backface-visibility: visible !important;
- -o-animation-name: flipOutX;
- -o-backface-visibility: visible !important;
- animation-name: flipOutX;
- backface-visibility: visible !important;
-}
-@-webkit-keyframes flipInY {
- 0% {
- -webkit-transform: perspective(400px) rotateY(90deg);
- opacity: 0;
- }
-
- 40% {
- -webkit-transform: perspective(400px) rotateY(-10deg);
- }
-
- 70% {
- -webkit-transform: perspective(400px) rotateY(10deg);
- }
-
- 100% {
- -webkit-transform: perspective(400px) rotateY(0deg);
- opacity: 1;
- }
-}
-@-moz-keyframes flipInY {
- 0% {
- -moz-transform: perspective(400px) rotateY(90deg);
- opacity: 0;
- }
-
- 40% {
- -moz-transform: perspective(400px) rotateY(-10deg);
- }
-
- 70% {
- -moz-transform: perspective(400px) rotateY(10deg);
- }
-
- 100% {
- -moz-transform: perspective(400px) rotateY(0deg);
- opacity: 1;
- }
-}
-@-o-keyframes flipInY {
- 0% {
- -o-transform: perspective(400px) rotateY(90deg);
- opacity: 0;
- }
-
- 40% {
- -o-transform: perspective(400px) rotateY(-10deg);
- }
-
- 70% {
- -o-transform: perspective(400px) rotateY(10deg);
- }
-
- 100% {
- -o-transform: perspective(400px) rotateY(0deg);
- opacity: 1;
- }
-}
-@keyframes flipInY {
- 0% {
- transform: perspective(400px) rotateY(90deg);
- opacity: 0;
- }
-
- 40% {
- transform: perspective(400px) rotateY(-10deg);
- }
-
- 70% {
- transform: perspective(400px) rotateY(10deg);
- }
-
- 100% {
- transform: perspective(400px) rotateY(0deg);
- opacity: 1;
- }
-}
-
-.flipInY {
- -webkit-backface-visibility: visible !important;
- -webkit-animation-name: flipInY;
- -moz-backface-visibility: visible !important;
- -moz-animation-name: flipInY;
- -o-backface-visibility: visible !important;
- -o-animation-name: flipInY;
- backface-visibility: visible !important;
- animation-name: flipInY;
-}
-@-webkit-keyframes flipOutY {
- 0% {
- -webkit-transform: perspective(400px) rotateY(0deg);
- opacity: 1;
- }
- 100% {
- -webkit-transform: perspective(400px) rotateY(90deg);
- opacity: 0;
- }
-}
-@-moz-keyframes flipOutY {
- 0% {
- -moz-transform: perspective(400px) rotateY(0deg);
- opacity: 1;
- }
- 100% {
- -moz-transform: perspective(400px) rotateY(90deg);
- opacity: 0;
- }
-}
-@-o-keyframes flipOutY {
- 0% {
- -o-transform: perspective(400px) rotateY(0deg);
- opacity: 1;
- }
- 100% {
- -o-transform: perspective(400px) rotateY(90deg);
- opacity: 0;
- }
-}
-@keyframes flipOutY {
- 0% {
- transform: perspective(400px) rotateY(0deg);
- opacity: 1;
- }
- 100% {
- transform: perspective(400px) rotateY(90deg);
- opacity: 0;
- }
-}
-
-.flipOutY {
- -webkit-backface-visibility: visible !important;
- -webkit-animation-name: flipOutY;
- -moz-backface-visibility: visible !important;
- -moz-animation-name: flipOutY;
- -o-backface-visibility: visible !important;
- -o-animation-name: flipOutY;
- backface-visibility: visible !important;
- animation-name: flipOutY;
-}
-@-webkit-keyframes fadeIn {
- 0% {opacity: 0;}
- 100% {opacity: 1;}
-}
-
-@-moz-keyframes fadeIn {
- 0% {opacity: 0;}
- 100% {opacity: 1;}
-}
-
-@-o-keyframes fadeIn {
- 0% {opacity: 0;}
- 100% {opacity: 1;}
-}
-
-@keyframes fadeIn {
- 0% {opacity: 0;}
- 100% {opacity: 1;}
-}
-
-.fadeIn {
- -webkit-animation-name: fadeIn;
- -moz-animation-name: fadeIn;
- -o-animation-name: fadeIn;
- animation-name: fadeIn;
-}
-@-webkit-keyframes fadeInUp {
- 0% {
- opacity: 0;
- -webkit-transform: translateY(20px);
- }
-
- 100% {
- opacity: 1;
- -webkit-transform: translateY(0);
- }
-}
-
-@-moz-keyframes fadeInUp {
- 0% {
- opacity: 0;
- -moz-transform: translateY(20px);
- }
-
- 100% {
- opacity: 1;
- -moz-transform: translateY(0);
- }
-}
-
-@-o-keyframes fadeInUp {
- 0% {
- opacity: 0;
- -o-transform: translateY(20px);
- }
-
- 100% {
- opacity: 1;
- -o-transform: translateY(0);
- }
-}
-
-@keyframes fadeInUp {
- 0% {
- opacity: 0;
- transform: translateY(20px);
- }
-
- 100% {
- opacity: 1;
- transform: translateY(0);
- }
-}
-
-.fadeInUp {
- -webkit-animation-name: fadeInUp;
- -moz-animation-name: fadeInUp;
- -o-animation-name: fadeInUp;
- animation-name: fadeInUp;
-}
-@-webkit-keyframes fadeInDown {
- 0% {
- opacity: 0;
- -webkit-transform: translateY(-20px);
- }
-
- 100% {
- opacity: 1;
- -webkit-transform: translateY(0);
- }
-}
-
-@-moz-keyframes fadeInDown {
- 0% {
- opacity: 0;
- -moz-transform: translateY(-20px);
- }
-
- 100% {
- opacity: 1;
- -moz-transform: translateY(0);
- }
-}
-
-@-o-keyframes fadeInDown {
- 0% {
- opacity: 0;
- -o-transform: translateY(-20px);
- }
-
- 100% {
- opacity: 1;
- -o-transform: translateY(0);
- }
-}
-
-@keyframes fadeInDown {
- 0% {
- opacity: 0;
- transform: translateY(-20px);
- }
-
- 100% {
- opacity: 1;
- transform: translateY(0);
- }
-}
-
-.fadeInDown {
- -webkit-animation-name: fadeInDown;
- -moz-animation-name: fadeInDown;
- -o-animation-name: fadeInDown;
- animation-name: fadeInDown;
-}
-@-webkit-keyframes fadeInLeft {
- 0% {
- opacity: 0;
- -webkit-transform: translateX(-20px);
- }
-
- 100% {
- opacity: 1;
- -webkit-transform: translateX(0);
- }
-}
-
-@-moz-keyframes fadeInLeft {
- 0% {
- opacity: 0;
- -moz-transform: translateX(-20px);
- }
-
- 100% {
- opacity: 1;
- -moz-transform: translateX(0);
- }
-}
-
-@-o-keyframes fadeInLeft {
- 0% {
- opacity: 0;
- -o-transform: translateX(-20px);
- }
-
- 100% {
- opacity: 1;
- -o-transform: translateX(0);
- }
-}
-
-@keyframes fadeInLeft {
- 0% {
- opacity: 0;
- transform: translateX(-20px);
- }
-
- 100% {
- opacity: 1;
- transform: translateX(0);
- }
-}
-
-.fadeInLeft {
- -webkit-animation-name: fadeInLeft;
- -moz-animation-name: fadeInLeft;
- -o-animation-name: fadeInLeft;
- animation-name: fadeInLeft;
-}
-@-webkit-keyframes fadeInRight {
- 0% {
- opacity: 0;
- -webkit-transform: translateX(20px);
- }
-
- 100% {
- opacity: 1;
- -webkit-transform: translateX(0);
- }
-}
-
-@-moz-keyframes fadeInRight {
- 0% {
- opacity: 0;
- -moz-transform: translateX(20px);
- }
-
- 100% {
- opacity: 1;
- -moz-transform: translateX(0);
- }
-}
-
-@-o-keyframes fadeInRight {
- 0% {
- opacity: 0;
- -o-transform: translateX(20px);
- }
-
- 100% {
- opacity: 1;
- -o-transform: translateX(0);
- }
-}
-
-@keyframes fadeInRight {
- 0% {
- opacity: 0;
- transform: translateX(20px);
- }
-
- 100% {
- opacity: 1;
- transform: translateX(0);
- }
-}
-
-.fadeInRight {
- -webkit-animation-name: fadeInRight;
- -moz-animation-name: fadeInRight;
- -o-animation-name: fadeInRight;
- animation-name: fadeInRight;
-}
-@-webkit-keyframes fadeInUpBig {
- 0% {
- opacity: 0;
- -webkit-transform: translateY(2000px);
- }
-
- 100% {
- opacity: 1;
- -webkit-transform: translateY(0);
- }
-}
-
-@-moz-keyframes fadeInUpBig {
- 0% {
- opacity: 0;
- -moz-transform: translateY(2000px);
- }
-
- 100% {
- opacity: 1;
- -moz-transform: translateY(0);
- }
-}
-
-@-o-keyframes fadeInUpBig {
- 0% {
- opacity: 0;
- -o-transform: translateY(2000px);
- }
-
- 100% {
- opacity: 1;
- -o-transform: translateY(0);
- }
-}
-
-@keyframes fadeInUpBig {
- 0% {
- opacity: 0;
- transform: translateY(2000px);
- }
-
- 100% {
- opacity: 1;
- transform: translateY(0);
- }
-}
-
-.fadeInUpBig {
- -webkit-animation-name: fadeInUpBig;
- -moz-animation-name: fadeInUpBig;
- -o-animation-name: fadeInUpBig;
- animation-name: fadeInUpBig;
-}
-@-webkit-keyframes fadeInDownBig {
- 0% {
- opacity: 0;
- -webkit-transform: translateY(-2000px);
- }
-
- 100% {
- opacity: 1;
- -webkit-transform: translateY(0);
- }
-}
-
-@-moz-keyframes fadeInDownBig {
- 0% {
- opacity: 0;
- -moz-transform: translateY(-2000px);
- }
-
- 100% {
- opacity: 1;
- -moz-transform: translateY(0);
- }
-}
-
-@-o-keyframes fadeInDownBig {
- 0% {
- opacity: 0;
- -o-transform: translateY(-2000px);
- }
-
- 100% {
- opacity: 1;
- -o-transform: translateY(0);
- }
-}
-
-@keyframes fadeInDownBig {
- 0% {
- opacity: 0;
- transform: translateY(-2000px);
- }
-
- 100% {
- opacity: 1;
- transform: translateY(0);
- }
-}
-
-.fadeInDownBig {
- -webkit-animation-name: fadeInDownBig;
- -moz-animation-name: fadeInDownBig;
- -o-animation-name: fadeInDownBig;
- animation-name: fadeInDownBig;
-}
-@-webkit-keyframes fadeInLeftBig {
- 0% {
- opacity: 0;
- -webkit-transform: translateX(-2000px);
- }
-
- 100% {
- opacity: 1;
- -webkit-transform: translateX(0);
- }
-}
-@-moz-keyframes fadeInLeftBig {
- 0% {
- opacity: 0;
- -moz-transform: translateX(-2000px);
- }
-
- 100% {
- opacity: 1;
- -moz-transform: translateX(0);
- }
-}
-@-o-keyframes fadeInLeftBig {
- 0% {
- opacity: 0;
- -o-transform: translateX(-2000px);
- }
-
- 100% {
- opacity: 1;
- -o-transform: translateX(0);
- }
-}
-@keyframes fadeInLeftBig {
- 0% {
- opacity: 0;
- transform: translateX(-2000px);
- }
-
- 100% {
- opacity: 1;
- transform: translateX(0);
- }
-}
-
-.fadeInLeftBig {
- -webkit-animation-name: fadeInLeftBig;
- -moz-animation-name: fadeInLeftBig;
- -o-animation-name: fadeInLeftBig;
- animation-name: fadeInLeftBig;
-}
-@-webkit-keyframes fadeInRightBig {
- 0% {
- opacity: 0;
- -webkit-transform: translateX(2000px);
- }
-
- 100% {
- opacity: 1;
- -webkit-transform: translateX(0);
- }
-}
-
-@-moz-keyframes fadeInRightBig {
- 0% {
- opacity: 0;
- -moz-transform: translateX(2000px);
- }
-
- 100% {
- opacity: 1;
- -moz-transform: translateX(0);
- }
-}
-
-@-o-keyframes fadeInRightBig {
- 0% {
- opacity: 0;
- -o-transform: translateX(2000px);
- }
-
- 100% {
- opacity: 1;
- -o-transform: translateX(0);
- }
-}
-
-@keyframes fadeInRightBig {
- 0% {
- opacity: 0;
- transform: translateX(2000px);
- }
-
- 100% {
- opacity: 1;
- transform: translateX(0);
- }
-}
-
-.fadeInRightBig {
- -webkit-animation-name: fadeInRightBig;
- -moz-animation-name: fadeInRightBig;
- -o-animation-name: fadeInRightBig;
- animation-name: fadeInRightBig;
-}
-@-webkit-keyframes fadeOut {
- 0% {opacity: 1;}
- 100% {opacity: 0;}
-}
-
-@-moz-keyframes fadeOut {
- 0% {opacity: 1;}
- 100% {opacity: 0;}
-}
-
-@-o-keyframes fadeOut {
- 0% {opacity: 1;}
- 100% {opacity: 0;}
-}
-
-@keyframes fadeOut {
- 0% {opacity: 1;}
- 100% {opacity: 0;}
-}
-
-.fadeOut {
- -webkit-animation-name: fadeOut;
- -moz-animation-name: fadeOut;
- -o-animation-name: fadeOut;
- animation-name: fadeOut;
-}
-@-webkit-keyframes fadeOutUp {
- 0% {
- opacity: 1;
- -webkit-transform: translateY(0);
- }
-
- 100% {
- opacity: 0;
- -webkit-transform: translateY(-20px);
- }
-}
-@-moz-keyframes fadeOutUp {
- 0% {
- opacity: 1;
- -moz-transform: translateY(0);
- }
-
- 100% {
- opacity: 0;
- -moz-transform: translateY(-20px);
- }
-}
-@-o-keyframes fadeOutUp {
- 0% {
- opacity: 1;
- -o-transform: translateY(0);
- }
-
- 100% {
- opacity: 0;
- -o-transform: translateY(-20px);
- }
-}
-@keyframes fadeOutUp {
- 0% {
- opacity: 1;
- transform: translateY(0);
- }
-
- 100% {
- opacity: 0;
- transform: translateY(-20px);
- }
-}
-
-.fadeOutUp {
- -webkit-animation-name: fadeOutUp;
- -moz-animation-name: fadeOutUp;
- -o-animation-name: fadeOutUp;
- animation-name: fadeOutUp;
-}
-@-webkit-keyframes fadeOutDown {
- 0% {
- opacity: 1;
- -webkit-transform: translateY(0);
- }
-
- 100% {
- opacity: 0;
- -webkit-transform: translateY(20px);
- }
-}
-
-@-moz-keyframes fadeOutDown {
- 0% {
- opacity: 1;
- -moz-transform: translateY(0);
- }
-
- 100% {
- opacity: 0;
- -moz-transform: translateY(20px);
- }
-}
-
-@-o-keyframes fadeOutDown {
- 0% {
- opacity: 1;
- -o-transform: translateY(0);
- }
-
- 100% {
- opacity: 0;
- -o-transform: translateY(20px);
- }
-}
-
-@keyframes fadeOutDown {
- 0% {
- opacity: 1;
- transform: translateY(0);
- }
-
- 100% {
- opacity: 0;
- transform: translateY(20px);
- }
-}
-
-.fadeOutDown {
- -webkit-animation-name: fadeOutDown;
- -moz-animation-name: fadeOutDown;
- -o-animation-name: fadeOutDown;
- animation-name: fadeOutDown;
-}
-@-webkit-keyframes fadeOutLeft {
- 0% {
- opacity: 1;
- -webkit-transform: translateX(0);
- }
-
- 100% {
- opacity: 0;
- -webkit-transform: translateX(-20px);
- }
-}
-
-@-moz-keyframes fadeOutLeft {
- 0% {
- opacity: 1;
- -moz-transform: translateX(0);
- }
-
- 100% {
- opacity: 0;
- -moz-transform: translateX(-20px);
- }
-}
-
-@-o-keyframes fadeOutLeft {
- 0% {
- opacity: 1;
- -o-transform: translateX(0);
- }
-
- 100% {
- opacity: 0;
- -o-transform: translateX(-20px);
- }
-}
-
-@keyframes fadeOutLeft {
- 0% {
- opacity: 1;
- transform: translateX(0);
- }
-
- 100% {
- opacity: 0;
- transform: translateX(-20px);
- }
-}
-
-.fadeOutLeft {
- -webkit-animation-name: fadeOutLeft;
- -moz-animation-name: fadeOutLeft;
- -o-animation-name: fadeOutLeft;
- animation-name: fadeOutLeft;
-}
-@-webkit-keyframes fadeOutRight {
- 0% {
- opacity: 1;
- -webkit-transform: translateX(0);
- }
-
- 100% {
- opacity: 0;
- -webkit-transform: translateX(20px);
- }
-}
-
-@-moz-keyframes fadeOutRight {
- 0% {
- opacity: 1;
- -moz-transform: translateX(0);
- }
-
- 100% {
- opacity: 0;
- -moz-transform: translateX(20px);
- }
-}
-
-@-o-keyframes fadeOutRight {
- 0% {
- opacity: 1;
- -o-transform: translateX(0);
- }
-
- 100% {
- opacity: 0;
- -o-transform: translateX(20px);
- }
-}
-
-@keyframes fadeOutRight {
- 0% {
- opacity: 1;
- transform: translateX(0);
- }
-
- 100% {
- opacity: 0;
- transform: translateX(20px);
- }
-}
-
-.fadeOutRight {
- -webkit-animation-name: fadeOutRight;
- -moz-animation-name: fadeOutRight;
- -o-animation-name: fadeOutRight;
- animation-name: fadeOutRight;
-}
-@-webkit-keyframes fadeOutUpBig {
- 0% {
- opacity: 1;
- -webkit-transform: translateY(0);
- }
-
- 100% {
- opacity: 0;
- -webkit-transform: translateY(-2000px);
- }
-}
-
-@-moz-keyframes fadeOutUpBig {
- 0% {
- opacity: 1;
- -moz-transform: translateY(0);
- }
-
- 100% {
- opacity: 0;
- -moz-transform: translateY(-2000px);
- }
-}
-
-@-o-keyframes fadeOutUpBig {
- 0% {
- opacity: 1;
- -o-transform: translateY(0);
- }
-
- 100% {
- opacity: 0;
- -o-transform: translateY(-2000px);
- }
-}
-
-@keyframes fadeOutUpBig {
- 0% {
- opacity: 1;
- transform: translateY(0);
- }
-
- 100% {
- opacity: 0;
- transform: translateY(-2000px);
- }
-}
-
-.fadeOutUpBig {
- -webkit-animation-name: fadeOutUpBig;
- -moz-animation-name: fadeOutUpBig;
- -o-animation-name: fadeOutUpBig;
- animation-name: fadeOutUpBig;
-}
-@-webkit-keyframes fadeOutDownBig {
- 0% {
- opacity: 1;
- -webkit-transform: translateY(0);
- }
-
- 100% {
- opacity: 0;
- -webkit-transform: translateY(2000px);
- }
-}
-
-@-moz-keyframes fadeOutDownBig {
- 0% {
- opacity: 1;
- -moz-transform: translateY(0);
- }
-
- 100% {
- opacity: 0;
- -moz-transform: translateY(2000px);
- }
-}
-
-@-o-keyframes fadeOutDownBig {
- 0% {
- opacity: 1;
- -o-transform: translateY(0);
- }
-
- 100% {
- opacity: 0;
- -o-transform: translateY(2000px);
- }
-}
-
-@keyframes fadeOutDownBig {
- 0% {
- opacity: 1;
- transform: translateY(0);
- }
-
- 100% {
- opacity: 0;
- transform: translateY(2000px);
- }
-}
-
-.fadeOutDownBig {
- -webkit-animation-name: fadeOutDownBig;
- -moz-animation-name: fadeOutDownBig;
- -o-animation-name: fadeOutDownBig;
- animation-name: fadeOutDownBig;
-}
-@-webkit-keyframes fadeOutLeftBig {
- 0% {
- opacity: 1;
- -webkit-transform: translateX(0);
- }
-
- 100% {
- opacity: 0;
- -webkit-transform: translateX(-2000px);
- }
-}
-
-@-moz-keyframes fadeOutLeftBig {
- 0% {
- opacity: 1;
- -moz-transform: translateX(0);
- }
-
- 100% {
- opacity: 0;
- -moz-transform: translateX(-2000px);
- }
-}
-
-@-o-keyframes fadeOutLeftBig {
- 0% {
- opacity: 1;
- -o-transform: translateX(0);
- }
-
- 100% {
- opacity: 0;
- -o-transform: translateX(-2000px);
- }
-}
-
-@keyframes fadeOutLeftBig {
- 0% {
- opacity: 1;
- transform: translateX(0);
- }
-
- 100% {
- opacity: 0;
- transform: translateX(-2000px);
- }
-}
-
-.fadeOutLeftBig {
- -webkit-animation-name: fadeOutLeftBig;
- -moz-animation-name: fadeOutLeftBig;
- -o-animation-name: fadeOutLeftBig;
- animation-name: fadeOutLeftBig;
-}
-@-webkit-keyframes fadeOutRightBig {
- 0% {
- opacity: 1;
- -webkit-transform: translateX(0);
- }
-
- 100% {
- opacity: 0;
- -webkit-transform: translateX(2000px);
- }
-}
-@-moz-keyframes fadeOutRightBig {
- 0% {
- opacity: 1;
- -moz-transform: translateX(0);
- }
-
- 100% {
- opacity: 0;
- -moz-transform: translateX(2000px);
- }
-}
-@-o-keyframes fadeOutRightBig {
- 0% {
- opacity: 1;
- -o-transform: translateX(0);
- }
-
- 100% {
- opacity: 0;
- -o-transform: translateX(2000px);
- }
-}
-@keyframes fadeOutRightBig {
- 0% {
- opacity: 1;
- transform: translateX(0);
- }
-
- 100% {
- opacity: 0;
- transform: translateX(2000px);
- }
-}
-
-.fadeOutRightBig {
- -webkit-animation-name: fadeOutRightBig;
- -moz-animation-name: fadeOutRightBig;
- -o-animation-name: fadeOutRightBig;
- animation-name: fadeOutRightBig;
-}
-@-webkit-keyframes bounceIn {
- 0% {
- opacity: 0;
- -webkit-transform: scale(.3);
- }
-
- 50% {
- opacity: 1;
- -webkit-transform: scale(1.05);
- }
-
- 70% {
- -webkit-transform: scale(.9);
- }
-
- 100% {
- -webkit-transform: scale(1);
- }
-}
-
-@-moz-keyframes bounceIn {
- 0% {
- opacity: 0;
- -moz-transform: scale(.3);
- }
-
- 50% {
- opacity: 1;
- -moz-transform: scale(1.05);
- }
-
- 70% {
- -moz-transform: scale(.9);
- }
-
- 100% {
- -moz-transform: scale(1);
- }
-}
-
-@-o-keyframes bounceIn {
- 0% {
- opacity: 0;
- -o-transform: scale(.3);
- }
-
- 50% {
- opacity: 1;
- -o-transform: scale(1.05);
- }
-
- 70% {
- -o-transform: scale(.9);
- }
-
- 100% {
- -o-transform: scale(1);
- }
-}
-
-@keyframes bounceIn {
- 0% {
- opacity: 0;
- transform: scale(.3);
- }
-
- 50% {
- opacity: 1;
- transform: scale(1.05);
- }
-
- 70% {
- transform: scale(.9);
- }
-
- 100% {
- transform: scale(1);
- }
-}
-
-.bounceIn {
- -webkit-animation-name: bounceIn;
- -moz-animation-name: bounceIn;
- -o-animation-name: bounceIn;
- animation-name: bounceIn;
-}
-@-webkit-keyframes bounceInUp {
- 0% {
- opacity: 0;
- -webkit-transform: translateY(2000px);
- }
-
- 60% {
- opacity: 1;
- -webkit-transform: translateY(-30px);
- }
-
- 80% {
- -webkit-transform: translateY(10px);
- }
-
- 100% {
- -webkit-transform: translateY(0);
- }
-}
-@-moz-keyframes bounceInUp {
- 0% {
- opacity: 0;
- -moz-transform: translateY(2000px);
- }
-
- 60% {
- opacity: 1;
- -moz-transform: translateY(-30px);
- }
-
- 80% {
- -moz-transform: translateY(10px);
- }
-
- 100% {
- -moz-transform: translateY(0);
- }
-}
-
-@-o-keyframes bounceInUp {
- 0% {
- opacity: 0;
- -o-transform: translateY(2000px);
- }
-
- 60% {
- opacity: 1;
- -o-transform: translateY(-30px);
- }
-
- 80% {
- -o-transform: translateY(10px);
- }
-
- 100% {
- -o-transform: translateY(0);
- }
-}
-
-@keyframes bounceInUp {
- 0% {
- opacity: 0;
- transform: translateY(2000px);
- }
-
- 60% {
- opacity: 1;
- transform: translateY(-30px);
- }
-
- 80% {
- transform: translateY(10px);
- }
-
- 100% {
- transform: translateY(0);
- }
-}
-
-.bounceInUp {
- -webkit-animation-name: bounceInUp;
- -moz-animation-name: bounceInUp;
- -o-animation-name: bounceInUp;
- animation-name: bounceInUp;
-}
-@-webkit-keyframes bounceInDown {
- 0% {
- opacity: 0;
- -webkit-transform: translateY(-2000px);
- }
-
- 60% {
- opacity: 1;
- -webkit-transform: translateY(30px);
- }
-
- 80% {
- -webkit-transform: translateY(-10px);
- }
-
- 100% {
- -webkit-transform: translateY(0);
- }
-}
-
-@-moz-keyframes bounceInDown {
- 0% {
- opacity: 0;
- -moz-transform: translateY(-2000px);
- }
-
- 60% {
- opacity: 1;
- -moz-transform: translateY(30px);
- }
-
- 80% {
- -moz-transform: translateY(-10px);
- }
-
- 100% {
- -moz-transform: translateY(0);
- }
-}
-
-@-o-keyframes bounceInDown {
- 0% {
- opacity: 0;
- -o-transform: translateY(-2000px);
- }
-
- 60% {
- opacity: 1;
- -o-transform: translateY(30px);
- }
-
- 80% {
- -o-transform: translateY(-10px);
- }
-
- 100% {
- -o-transform: translateY(0);
- }
-}
-
-@keyframes bounceInDown {
- 0% {
- opacity: 0;
- transform: translateY(-2000px);
- }
-
- 60% {
- opacity: 1;
- transform: translateY(30px);
- }
-
- 80% {
- transform: translateY(-10px);
- }
-
- 100% {
- transform: translateY(0);
- }
-}
-
-.bounceInDown {
- -webkit-animation-name: bounceInDown;
- -moz-animation-name: bounceInDown;
- -o-animation-name: bounceInDown;
- animation-name: bounceInDown;
-}
-@-webkit-keyframes bounceInLeft {
- 0% {
- opacity: 0;
- -webkit-transform: translateX(-2000px);
- }
-
- 60% {
- opacity: 1;
- -webkit-transform: translateX(30px);
- }
-
- 80% {
- -webkit-transform: translateX(-10px);
- }
-
- 100% {
- -webkit-transform: translateX(0);
- }
-}
-
-@-moz-keyframes bounceInLeft {
- 0% {
- opacity: 0;
- -moz-transform: translateX(-2000px);
- }
-
- 60% {
- opacity: 1;
- -moz-transform: translateX(30px);
- }
-
- 80% {
- -moz-transform: translateX(-10px);
- }
-
- 100% {
- -moz-transform: translateX(0);
- }
-}
-
-@-o-keyframes bounceInLeft {
- 0% {
- opacity: 0;
- -o-transform: translateX(-2000px);
- }
-
- 60% {
- opacity: 1;
- -o-transform: translateX(30px);
- }
-
- 80% {
- -o-transform: translateX(-10px);
- }
-
- 100% {
- -o-transform: translateX(0);
- }
-}
-
-@keyframes bounceInLeft {
- 0% {
- opacity: 0;
- transform: translateX(-2000px);
- }
-
- 60% {
- opacity: 1;
- transform: translateX(30px);
- }
-
- 80% {
- transform: translateX(-10px);
- }
-
- 100% {
- transform: translateX(0);
- }
-}
-
-.bounceInLeft {
- -webkit-animation-name: bounceInLeft;
- -moz-animation-name: bounceInLeft;
- -o-animation-name: bounceInLeft;
- animation-name: bounceInLeft;
-}
-@-webkit-keyframes bounceInRight {
- 0% {
- opacity: 0;
- -webkit-transform: translateX(2000px);
- }
-
- 60% {
- opacity: 1;
- -webkit-transform: translateX(-30px);
- }
-
- 80% {
- -webkit-transform: translateX(10px);
- }
-
- 100% {
- -webkit-transform: translateX(0);
- }
-}
-
-@-moz-keyframes bounceInRight {
- 0% {
- opacity: 0;
- -moz-transform: translateX(2000px);
- }
-
- 60% {
- opacity: 1;
- -moz-transform: translateX(-30px);
- }
-
- 80% {
- -moz-transform: translateX(10px);
- }
-
- 100% {
- -moz-transform: translateX(0);
- }
-}
-
-@-o-keyframes bounceInRight {
- 0% {
- opacity: 0;
- -o-transform: translateX(2000px);
- }
-
- 60% {
- opacity: 1;
- -o-transform: translateX(-30px);
- }
-
- 80% {
- -o-transform: translateX(10px);
- }
-
- 100% {
- -o-transform: translateX(0);
- }
-}
-
-@keyframes bounceInRight {
- 0% {
- opacity: 0;
- transform: translateX(2000px);
- }
-
- 60% {
- opacity: 1;
- transform: translateX(-30px);
- }
-
- 80% {
- transform: translateX(10px);
- }
-
- 100% {
- transform: translateX(0);
- }
-}
-
-.bounceInRight {
- -webkit-animation-name: bounceInRight;
- -moz-animation-name: bounceInRight;
- -o-animation-name: bounceInRight;
- animation-name: bounceInRight;
-}
-@-webkit-keyframes bounceOut {
- 0% {
- -webkit-transform: scale(1);
- }
-
- 25% {
- -webkit-transform: scale(.95);
- }
-
- 50% {
- opacity: 1;
- -webkit-transform: scale(1.1);
- }
-
- 100% {
- opacity: 0;
- -webkit-transform: scale(.3);
- }
-}
-
-@-moz-keyframes bounceOut {
- 0% {
- -moz-transform: scale(1);
- }
-
- 25% {
- -moz-transform: scale(.95);
- }
-
- 50% {
- opacity: 1;
- -moz-transform: scale(1.1);
- }
-
- 100% {
- opacity: 0;
- -moz-transform: scale(.3);
- }
-}
-
-@-o-keyframes bounceOut {
- 0% {
- -o-transform: scale(1);
- }
-
- 25% {
- -o-transform: scale(.95);
- }
-
- 50% {
- opacity: 1;
- -o-transform: scale(1.1);
- }
-
- 100% {
- opacity: 0;
- -o-transform: scale(.3);
- }
-}
-
-@keyframes bounceOut {
- 0% {
- transform: scale(1);
- }
-
- 25% {
- transform: scale(.95);
- }
-
- 50% {
- opacity: 1;
- transform: scale(1.1);
- }
-
- 100% {
- opacity: 0;
- transform: scale(.3);
- }
-}
-
-.bounceOut {
- -webkit-animation-name: bounceOut;
- -moz-animation-name: bounceOut;
- -o-animation-name: bounceOut;
- animation-name: bounceOut;
-}
-@-webkit-keyframes bounceOutUp {
- 0% {
- -webkit-transform: translateY(0);
- }
-
- 20% {
- opacity: 1;
- -webkit-transform: translateY(20px);
- }
-
- 100% {
- opacity: 0;
- -webkit-transform: translateY(-2000px);
- }
-}
-
-@-moz-keyframes bounceOutUp {
- 0% {
- -moz-transform: translateY(0);
- }
-
- 20% {
- opacity: 1;
- -moz-transform: translateY(20px);
- }
-
- 100% {
- opacity: 0;
- -moz-transform: translateY(-2000px);
- }
-}
-
-@-o-keyframes bounceOutUp {
- 0% {
- -o-transform: translateY(0);
- }
-
- 20% {
- opacity: 1;
- -o-transform: translateY(20px);
- }
-
- 100% {
- opacity: 0;
- -o-transform: translateY(-2000px);
- }
-}
-
-@keyframes bounceOutUp {
- 0% {
- transform: translateY(0);
- }
-
- 20% {
- opacity: 1;
- transform: translateY(20px);
- }
-
- 100% {
- opacity: 0;
- transform: translateY(-2000px);
- }
-}
-
-.bounceOutUp {
- -webkit-animation-name: bounceOutUp;
- -moz-animation-name: bounceOutUp;
- -o-animation-name: bounceOutUp;
- animation-name: bounceOutUp;
-}
-@-webkit-keyframes bounceOutDown {
- 0% {
- -webkit-transform: translateY(0);
- }
-
- 20% {
- opacity: 1;
- -webkit-transform: translateY(-20px);
- }
-
- 100% {
- opacity: 0;
- -webkit-transform: translateY(2000px);
- }
-}
-
-@-moz-keyframes bounceOutDown {
- 0% {
- -moz-transform: translateY(0);
- }
-
- 20% {
- opacity: 1;
- -moz-transform: translateY(-20px);
- }
-
- 100% {
- opacity: 0;
- -moz-transform: translateY(2000px);
- }
-}
-
-@-o-keyframes bounceOutDown {
- 0% {
- -o-transform: translateY(0);
- }
-
- 20% {
- opacity: 1;
- -o-transform: translateY(-20px);
- }
-
- 100% {
- opacity: 0;
- -o-transform: translateY(2000px);
- }
-}
-
-@keyframes bounceOutDown {
- 0% {
- transform: translateY(0);
- }
-
- 20% {
- opacity: 1;
- transform: translateY(-20px);
- }
-
- 100% {
- opacity: 0;
- transform: translateY(2000px);
- }
-}
-
-.bounceOutDown {
- -webkit-animation-name: bounceOutDown;
- -moz-animation-name: bounceOutDown;
- -o-animation-name: bounceOutDown;
- animation-name: bounceOutDown;
-}
-@-webkit-keyframes bounceOutLeft {
- 0% {
- -webkit-transform: translateX(0);
- }
-
- 20% {
- opacity: 1;
- -webkit-transform: translateX(20px);
- }
-
- 100% {
- opacity: 0;
- -webkit-transform: translateX(-2000px);
- }
-}
-
-@-moz-keyframes bounceOutLeft {
- 0% {
- -moz-transform: translateX(0);
- }
-
- 20% {
- opacity: 1;
- -moz-transform: translateX(20px);
- }
-
- 100% {
- opacity: 0;
- -moz-transform: translateX(-2000px);
- }
-}
-
-@-o-keyframes bounceOutLeft {
- 0% {
- -o-transform: translateX(0);
- }
-
- 20% {
- opacity: 1;
- -o-transform: translateX(20px);
- }
-
- 100% {
- opacity: 0;
- -o-transform: translateX(-2000px);
- }
-}
-
-@keyframes bounceOutLeft {
- 0% {
- transform: translateX(0);
- }
-
- 20% {
- opacity: 1;
- transform: translateX(20px);
- }
-
- 100% {
- opacity: 0;
- transform: translateX(-2000px);
- }
-}
-
-.bounceOutLeft {
- -webkit-animation-name: bounceOutLeft;
- -moz-animation-name: bounceOutLeft;
- -o-animation-name: bounceOutLeft;
- animation-name: bounceOutLeft;
-}
-@-webkit-keyframes bounceOutRight {
- 0% {
- -webkit-transform: translateX(0);
- }
-
- 20% {
- opacity: 1;
- -webkit-transform: translateX(-20px);
- }
-
- 100% {
- opacity: 0;
- -webkit-transform: translateX(2000px);
- }
-}
-
-@-moz-keyframes bounceOutRight {
- 0% {
- -moz-transform: translateX(0);
- }
-
- 20% {
- opacity: 1;
- -moz-transform: translateX(-20px);
- }
-
- 100% {
- opacity: 0;
- -moz-transform: translateX(2000px);
- }
-}
-
-@-o-keyframes bounceOutRight {
- 0% {
- -o-transform: translateX(0);
- }
-
- 20% {
- opacity: 1;
- -o-transform: translateX(-20px);
- }
-
- 100% {
- opacity: 0;
- -o-transform: translateX(2000px);
- }
-}
-
-@keyframes bounceOutRight {
- 0% {
- transform: translateX(0);
- }
-
- 20% {
- opacity: 1;
- transform: translateX(-20px);
- }
-
- 100% {
- opacity: 0;
- transform: translateX(2000px);
- }
-}
-
-.bounceOutRight {
- -webkit-animation-name: bounceOutRight;
- -moz-animation-name: bounceOutRight;
- -o-animation-name: bounceOutRight;
- animation-name: bounceOutRight;
-}
-@-webkit-keyframes rotateIn {
- 0% {
- -webkit-transform-origin: center center;
- -webkit-transform: rotate(-200deg);
- opacity: 0;
- }
-
- 100% {
- -webkit-transform-origin: center center;
- -webkit-transform: rotate(0);
- opacity: 1;
- }
-}
-@-moz-keyframes rotateIn {
- 0% {
- -moz-transform-origin: center center;
- -moz-transform: rotate(-200deg);
- opacity: 0;
- }
-
- 100% {
- -moz-transform-origin: center center;
- -moz-transform: rotate(0);
- opacity: 1;
- }
-}
-@-o-keyframes rotateIn {
- 0% {
- -o-transform-origin: center center;
- -o-transform: rotate(-200deg);
- opacity: 0;
- }
-
- 100% {
- -o-transform-origin: center center;
- -o-transform: rotate(0);
- opacity: 1;
- }
-}
-@keyframes rotateIn {
- 0% {
- transform-origin: center center;
- transform: rotate(-200deg);
- opacity: 0;
- }
-
- 100% {
- transform-origin: center center;
- transform: rotate(0);
- opacity: 1;
- }
-}
-
-.rotateIn {
- -webkit-animation-name: rotateIn;
- -moz-animation-name: rotateIn;
- -o-animation-name: rotateIn;
- animation-name: rotateIn;
-}
-@-webkit-keyframes rotateInUpLeft {
- 0% {
- -webkit-transform-origin: left bottom;
- -webkit-transform: rotate(90deg);
- opacity: 0;
- }
-
- 100% {
- -webkit-transform-origin: left bottom;
- -webkit-transform: rotate(0);
- opacity: 1;
- }
-}
-
-@-moz-keyframes rotateInUpLeft {
- 0% {
- -moz-transform-origin: left bottom;
- -moz-transform: rotate(90deg);
- opacity: 0;
- }
-
- 100% {
- -moz-transform-origin: left bottom;
- -moz-transform: rotate(0);
- opacity: 1;
- }
-}
-
-@-o-keyframes rotateInUpLeft {
- 0% {
- -o-transform-origin: left bottom;
- -o-transform: rotate(90deg);
- opacity: 0;
- }
-
- 100% {
- -o-transform-origin: left bottom;
- -o-transform: rotate(0);
- opacity: 1;
- }
-}
-
-@keyframes rotateInUpLeft {
- 0% {
- transform-origin: left bottom;
- transform: rotate(90deg);
- opacity: 0;
- }
-
- 100% {
- transform-origin: left bottom;
- transform: rotate(0);
- opacity: 1;
- }
-}
-
-.rotateInUpLeft {
- -webkit-animation-name: rotateInUpLeft;
- -moz-animation-name: rotateInUpLeft;
- -o-animation-name: rotateInUpLeft;
- animation-name: rotateInUpLeft;
-}
-@-webkit-keyframes rotateInDownLeft {
- 0% {
- -webkit-transform-origin: left bottom;
- -webkit-transform: rotate(-90deg);
- opacity: 0;
- }
-
- 100% {
- -webkit-transform-origin: left bottom;
- -webkit-transform: rotate(0);
- opacity: 1;
- }
-}
-
-@-moz-keyframes rotateInDownLeft {
- 0% {
- -moz-transform-origin: left bottom;
- -moz-transform: rotate(-90deg);
- opacity: 0;
- }
-
- 100% {
- -moz-transform-origin: left bottom;
- -moz-transform: rotate(0);
- opacity: 1;
- }
-}
-
-@-o-keyframes rotateInDownLeft {
- 0% {
- -o-transform-origin: left bottom;
- -o-transform: rotate(-90deg);
- opacity: 0;
- }
-
- 100% {
- -o-transform-origin: left bottom;
- -o-transform: rotate(0);
- opacity: 1;
- }
-}
-
-@keyframes rotateInDownLeft {
- 0% {
- transform-origin: left bottom;
- transform: rotate(-90deg);
- opacity: 0;
- }
-
- 100% {
- transform-origin: left bottom;
- transform: rotate(0);
- opacity: 1;
- }
-}
-
-.rotateInDownLeft {
- -webkit-animation-name: rotateInDownLeft;
- -moz-animation-name: rotateInDownLeft;
- -o-animation-name: rotateInDownLeft;
- animation-name: rotateInDownLeft;
-}
-@-webkit-keyframes rotateInUpRight {
- 0% {
- -webkit-transform-origin: right bottom;
- -webkit-transform: rotate(-90deg);
- opacity: 0;
- }
-
- 100% {
- -webkit-transform-origin: right bottom;
- -webkit-transform: rotate(0);
- opacity: 1;
- }
-}
-
-@-moz-keyframes rotateInUpRight {
- 0% {
- -moz-transform-origin: right bottom;
- -moz-transform: rotate(-90deg);
- opacity: 0;
- }
-
- 100% {
- -moz-transform-origin: right bottom;
- -moz-transform: rotate(0);
- opacity: 1;
- }
-}
-
-@-o-keyframes rotateInUpRight {
- 0% {
- -o-transform-origin: right bottom;
- -o-transform: rotate(-90deg);
- opacity: 0;
- }
-
- 100% {
- -o-transform-origin: right bottom;
- -o-transform: rotate(0);
- opacity: 1;
- }
-}
-
-@keyframes rotateInUpRight {
- 0% {
- transform-origin: right bottom;
- transform: rotate(-90deg);
- opacity: 0;
- }
-
- 100% {
- transform-origin: right bottom;
- transform: rotate(0);
- opacity: 1;
- }
-}
-
-.rotateInUpRight {
- -webkit-animation-name: rotateInUpRight;
- -moz-animation-name: rotateInUpRight;
- -o-animation-name: rotateInUpRight;
- animation-name: rotateInUpRight;
-}
-@-webkit-keyframes rotateInDownRight {
- 0% {
- -webkit-transform-origin: right bottom;
- -webkit-transform: rotate(90deg);
- opacity: 0;
- }
-
- 100% {
- -webkit-transform-origin: right bottom;
- -webkit-transform: rotate(0);
- opacity: 1;
- }
-}
-
-@-moz-keyframes rotateInDownRight {
- 0% {
- -moz-transform-origin: right bottom;
- -moz-transform: rotate(90deg);
- opacity: 0;
- }
-
- 100% {
- -moz-transform-origin: right bottom;
- -moz-transform: rotate(0);
- opacity: 1;
- }
-}
-
-@-o-keyframes rotateInDownRight {
- 0% {
- -o-transform-origin: right bottom;
- -o-transform: rotate(90deg);
- opacity: 0;
- }
-
- 100% {
- -o-transform-origin: right bottom;
- -o-transform: rotate(0);
- opacity: 1;
- }
-}
-
-@keyframes rotateInDownRight {
- 0% {
- transform-origin: right bottom;
- transform: rotate(90deg);
- opacity: 0;
- }
-
- 100% {
- transform-origin: right bottom;
- transform: rotate(0);
- opacity: 1;
- }
-}
-
-.rotateInDownRight {
- -webkit-animation-name: rotateInDownRight;
- -moz-animation-name: rotateInDownRight;
- -o-animation-name: rotateInDownRight;
- animation-name: rotateInDownRight;
-}
-@-webkit-keyframes rotateOut {
- 0% {
- -webkit-transform-origin: center center;
- -webkit-transform: rotate(0);
- opacity: 1;
- }
-
- 100% {
- -webkit-transform-origin: center center;
- -webkit-transform: rotate(200deg);
- opacity: 0;
- }
-}
-
-@-moz-keyframes rotateOut {
- 0% {
- -moz-transform-origin: center center;
- -moz-transform: rotate(0);
- opacity: 1;
- }
-
- 100% {
- -moz-transform-origin: center center;
- -moz-transform: rotate(200deg);
- opacity: 0;
- }
-}
-
-@-o-keyframes rotateOut {
- 0% {
- -o-transform-origin: center center;
- -o-transform: rotate(0);
- opacity: 1;
- }
-
- 100% {
- -o-transform-origin: center center;
- -o-transform: rotate(200deg);
- opacity: 0;
- }
-}
-
-@keyframes rotateOut {
- 0% {
- transform-origin: center center;
- transform: rotate(0);
- opacity: 1;
- }
-
- 100% {
- transform-origin: center center;
- transform: rotate(200deg);
- opacity: 0;
- }
-}
-
-.rotateOut {
- -webkit-animation-name: rotateOut;
- -moz-animation-name: rotateOut;
- -o-animation-name: rotateOut;
- animation-name: rotateOut;
-}
-@-webkit-keyframes rotateOutUpLeft {
- 0% {
- -webkit-transform-origin: left bottom;
- -webkit-transform: rotate(0);
- opacity: 1;
- }
-
- 100% {
- -webkit-transform-origin: left bottom;
- -webkit-transform: rotate(-90deg);
- opacity: 0;
- }
-}
-
-@-moz-keyframes rotateOutUpLeft {
- 0% {
- -moz-transform-origin: left bottom;
- -moz-transform: rotate(0);
- opacity: 1;
- }
-
- 100% {
- -moz-transform-origin: left bottom;
- -moz-transform: rotate(-90deg);
- opacity: 0;
- }
-}
-
-@-o-keyframes rotateOutUpLeft {
- 0% {
- -o-transform-origin: left bottom;
- -o-transform: rotate(0);
- opacity: 1;
- }
-
- 100% {
- -o-transform-origin: left bottom;
- -o-transform: rotate(-90deg);
- opacity: 0;
- }
-}
-
-@keyframes rotateOutUpLeft {
- 0% {
- transform-origin: left bottom;
- transform: rotate(0);
- opacity: 1;
- }
-
- 100% {
- transform-origin: left bottom;
- transform: rotate(-90deg);
- opacity: 0;
- }
-}
-
-.rotateOutUpLeft {
- -webkit-animation-name: rotateOutUpLeft;
- -moz-animation-name: rotateOutUpLeft;
- -o-animation-name: rotateOutUpLeft;
- animation-name: rotateOutUpLeft;
-}
-@-webkit-keyframes rotateOutDownLeft {
- 0% {
- -webkit-transform-origin: left bottom;
- -webkit-transform: rotate(0);
- opacity: 1;
- }
-
- 100% {
- -webkit-transform-origin: left bottom;
- -webkit-transform: rotate(90deg);
- opacity: 0;
- }
-}
-
-@-moz-keyframes rotateOutDownLeft {
- 0% {
- -moz-transform-origin: left bottom;
- -moz-transform: rotate(0);
- opacity: 1;
- }
-
- 100% {
- -moz-transform-origin: left bottom;
- -moz-transform: rotate(90deg);
- opacity: 0;
- }
-}
-
-@-o-keyframes rotateOutDownLeft {
- 0% {
- -o-transform-origin: left bottom;
- -o-transform: rotate(0);
- opacity: 1;
- }
-
- 100% {
- -o-transform-origin: left bottom;
- -o-transform: rotate(90deg);
- opacity: 0;
- }
-}
-
-@keyframes rotateOutDownLeft {
- 0% {
- transform-origin: left bottom;
- transform: rotate(0);
- opacity: 1;
- }
-
- 100% {
- transform-origin: left bottom;
- transform: rotate(90deg);
- opacity: 0;
- }
-}
-
-.rotateOutDownLeft {
- -webkit-animation-name: rotateOutDownLeft;
- -moz-animation-name: rotateOutDownLeft;
- -o-animation-name: rotateOutDownLeft;
- animation-name: rotateOutDownLeft;
-}
-@-webkit-keyframes rotateOutUpRight {
- 0% {
- -webkit-transform-origin: right bottom;
- -webkit-transform: rotate(0);
- opacity: 1;
- }
-
- 100% {
- -webkit-transform-origin: right bottom;
- -webkit-transform: rotate(90deg);
- opacity: 0;
- }
-}
-
-@-moz-keyframes rotateOutUpRight {
- 0% {
- -moz-transform-origin: right bottom;
- -moz-transform: rotate(0);
- opacity: 1;
- }
-
- 100% {
- -moz-transform-origin: right bottom;
- -moz-transform: rotate(90deg);
- opacity: 0;
- }
-}
-
-@-o-keyframes rotateOutUpRight {
- 0% {
- -o-transform-origin: right bottom;
- -o-transform: rotate(0);
- opacity: 1;
- }
-
- 100% {
- -o-transform-origin: right bottom;
- -o-transform: rotate(90deg);
- opacity: 0;
- }
-}
-
-@keyframes rotateOutUpRight {
- 0% {
- transform-origin: right bottom;
- transform: rotate(0);
- opacity: 1;
- }
-
- 100% {
- transform-origin: right bottom;
- transform: rotate(90deg);
- opacity: 0;
- }
-}
-
-.rotateOutUpRight {
- -webkit-animation-name: rotateOutUpRight;
- -moz-animation-name: rotateOutUpRight;
- -o-animation-name: rotateOutUpRight;
- animation-name: rotateOutUpRight;
-}
-@-webkit-keyframes rotateOutDownRight {
- 0% {
- -webkit-transform-origin: right bottom;
- -webkit-transform: rotate(0);
- opacity: 1;
- }
-
- 100% {
- -webkit-transform-origin: right bottom;
- -webkit-transform: rotate(-90deg);
- opacity: 0;
- }
-}
-
-@-moz-keyframes rotateOutDownRight {
- 0% {
- -moz-transform-origin: right bottom;
- -moz-transform: rotate(0);
- opacity: 1;
- }
-
- 100% {
- -moz-transform-origin: right bottom;
- -moz-transform: rotate(-90deg);
- opacity: 0;
- }
-}
-
-@-o-keyframes rotateOutDownRight {
- 0% {
- -o-transform-origin: right bottom;
- -o-transform: rotate(0);
- opacity: 1;
- }
-
- 100% {
- -o-transform-origin: right bottom;
- -o-transform: rotate(-90deg);
- opacity: 0;
- }
-}
-
-@keyframes rotateOutDownRight {
- 0% {
- transform-origin: right bottom;
- transform: rotate(0);
- opacity: 1;
- }
-
- 100% {
- transform-origin: right bottom;
- transform: rotate(-90deg);
- opacity: 0;
- }
-}
-
-.rotateOutDownRight {
- -webkit-animation-name: rotateOutDownRight;
- -moz-animation-name: rotateOutDownRight;
- -o-animation-name: rotateOutDownRight;
- animation-name: rotateOutDownRight;
-}
-@-webkit-keyframes hinge {
- 0% { -webkit-transform: rotate(0); -webkit-transform-origin: top left; -webkit-animation-timing-function: ease-in-out; }
- 20%, 60% { -webkit-transform: rotate(80deg); -webkit-transform-origin: top left; -webkit-animation-timing-function: ease-in-out; }
- 40% { -webkit-transform: rotate(60deg); -webkit-transform-origin: top left; -webkit-animation-timing-function: ease-in-out; }
- 80% { -webkit-transform: rotate(60deg) translateY(0); opacity: 1; -webkit-transform-origin: top left; -webkit-animation-timing-function: ease-in-out; }
- 100% { -webkit-transform: translateY(700px); opacity: 0; }
-}
-
-@-moz-keyframes hinge {
- 0% { -moz-transform: rotate(0); -moz-transform-origin: top left; -moz-animation-timing-function: ease-in-out; }
- 20%, 60% { -moz-transform: rotate(80deg); -moz-transform-origin: top left; -moz-animation-timing-function: ease-in-out; }
- 40% { -moz-transform: rotate(60deg); -moz-transform-origin: top left; -moz-animation-timing-function: ease-in-out; }
- 80% { -moz-transform: rotate(60deg) translateY(0); opacity: 1; -moz-transform-origin: top left; -moz-animation-timing-function: ease-in-out; }
- 100% { -moz-transform: translateY(700px); opacity: 0; }
-}
-
-@-o-keyframes hinge {
- 0% { -o-transform: rotate(0); -o-transform-origin: top left; -o-animation-timing-function: ease-in-out; }
- 20%, 60% { -o-transform: rotate(80deg); -o-transform-origin: top left; -o-animation-timing-function: ease-in-out; }
- 40% { -o-transform: rotate(60deg); -o-transform-origin: top left; -o-animation-timing-function: ease-in-out; }
- 80% { -o-transform: rotate(60deg) translateY(0); opacity: 1; -o-transform-origin: top left; -o-animation-timing-function: ease-in-out; }
- 100% { -o-transform: translateY(700px); opacity: 0; }
-}
-
-@keyframes hinge {
- 0% { transform: rotate(0); transform-origin: top left; animation-timing-function: ease-in-out; }
- 20%, 60% { transform: rotate(80deg); transform-origin: top left; animation-timing-function: ease-in-out; }
- 40% { transform: rotate(60deg); transform-origin: top left; animation-timing-function: ease-in-out; }
- 80% { transform: rotate(60deg) translateY(0); opacity: 1; transform-origin: top left; animation-timing-function: ease-in-out; }
- 100% { transform: translateY(700px); opacity: 0; }
-}
-
-.hinge {
- -webkit-animation-name: hinge;
- -moz-animation-name: hinge;
- -o-animation-name: hinge;
- animation-name: hinge;
-}
-/* originally authored by Nick Pettit - https://github.com/nickpettit/glide */
-
-@-webkit-keyframes rollIn {
- 0% { opacity: 0; -webkit-transform: translateX(-100%) rotate(-120deg); }
- 100% { opacity: 1; -webkit-transform: translateX(0px) rotate(0deg); }
-}
-
-@-moz-keyframes rollIn {
- 0% { opacity: 0; -moz-transform: translateX(-100%) rotate(-120deg); }
- 100% { opacity: 1; -moz-transform: translateX(0px) rotate(0deg); }
-}
-
-@-o-keyframes rollIn {
- 0% { opacity: 0; -o-transform: translateX(-100%) rotate(-120deg); }
- 100% { opacity: 1; -o-transform: translateX(0px) rotate(0deg); }
-}
-
-@keyframes rollIn {
- 0% { opacity: 0; transform: translateX(-100%) rotate(-120deg); }
- 100% { opacity: 1; transform: translateX(0px) rotate(0deg); }
-}
-
-.rollIn {
- -webkit-animation-name: rollIn;
- -moz-animation-name: rollIn;
- -o-animation-name: rollIn;
- animation-name: rollIn;
-}
-/* originally authored by Nick Pettit - https://github.com/nickpettit/glide */
-
-@-webkit-keyframes rollOut {
- 0% {
- opacity: 1;
- -webkit-transform: translateX(0px) rotate(0deg);
- }
-
- 100% {
- opacity: 0;
- -webkit-transform: translateX(100%) rotate(120deg);
- }
-}
-
-@-moz-keyframes rollOut {
- 0% {
- opacity: 1;
- -moz-transform: translateX(0px) rotate(0deg);
- }
-
- 100% {
- opacity: 0;
- -moz-transform: translateX(100%) rotate(120deg);
- }
-}
-
-@-o-keyframes rollOut {
- 0% {
- opacity: 1;
- -o-transform: translateX(0px) rotate(0deg);
- }
-
- 100% {
- opacity: 0;
- -o-transform: translateX(100%) rotate(120deg);
- }
-}
-
-@keyframes rollOut {
- 0% {
- opacity: 1;
- transform: translateX(0px) rotate(0deg);
- }
-
- 100% {
- opacity: 0;
- transform: translateX(100%) rotate(120deg);
- }
-}
-
-.rollOut {
- -webkit-animation-name: rollOut;
- -moz-animation-name: rollOut;
- -o-animation-name: rollOut;
- animation-name: rollOut;
-}
-
-/* originally authored by Angelo Rohit - https://github.com/angelorohit */
-
-@-webkit-keyframes lightSpeedIn {
- 0% { -webkit-transform: translateX(100%) skewX(-30deg); opacity: 0; }
- 60% { -webkit-transform: translateX(-20%) skewX(30deg); opacity: 1; }
- 80% { -webkit-transform: translateX(0%) skewX(-15deg); opacity: 1; }
- 100% { -webkit-transform: translateX(0%) skewX(0deg); opacity: 1; }
-}
-
-@-moz-keyframes lightSpeedIn {
- 0% { -moz-transform: translateX(100%) skewX(-30deg); opacity: 0; }
- 60% { -moz-transform: translateX(-20%) skewX(30deg); opacity: 1; }
- 80% { -moz-transform: translateX(0%) skewX(-15deg); opacity: 1; }
- 100% { -moz-transform: translateX(0%) skewX(0deg); opacity: 1; }
-}
-
-@-o-keyframes lightSpeedIn {
- 0% { -o-transform: translateX(100%) skewX(-30deg); opacity: 0; }
- 60% { -o-transform: translateX(-20%) skewX(30deg); opacity: 1; }
- 80% { -o-transform: translateX(0%) skewX(-15deg); opacity: 1; }
- 100% { -o-transform: translateX(0%) skewX(0deg); opacity: 1; }
-}
-
-@keyframes lightSpeedIn {
- 0% { transform: translateX(100%) skewX(-30deg); opacity: 0; }
- 60% { transform: translateX(-20%) skewX(30deg); opacity: 1; }
- 80% { transform: translateX(0%) skewX(-15deg); opacity: 1; }
- 100% { transform: translateX(0%) skewX(0deg); opacity: 1; }
-}
-
-.lightSpeedIn {
- -webkit-animation-name: lightSpeedIn;
- -moz-animation-name: lightSpeedIn;
- -o-animation-name: lightSpeedIn;
- animation-name: lightSpeedIn;
-
- -webkit-animation-timing-function: ease-out;
- -moz-animation-timing-function: ease-out;
- -o-animation-timing-function: ease-out;
- animation-timing-function: ease-out;
-}
-
-.animated.lightSpeedIn {
- -webkit-animation-duration: 0.5s;
- -moz-animation-duration: 0.5s;
- -o-animation-duration: 0.5s;
- animation-duration: 0.5s;
-}
-
-/* originally authored by Angelo Rohit - https://github.com/angelorohit */
-
-@-webkit-keyframes lightSpeedOut {
- 0% { -webkit-transform: translateX(0%) skewX(0deg); opacity: 1; }
- 100% { -webkit-transform: translateX(100%) skewX(-30deg); opacity: 0; }
-}
-
-@-moz-keyframes lightSpeedOut {
- 0% { -moz-transform: translateX(0%) skewX(0deg); opacity: 1; }
- 100% { -moz-transform: translateX(100%) skewX(-30deg); opacity: 0; }
-}
-
-@-o-keyframes lightSpeedOut {
- 0% { -o-transform: translateX(0%) skewX(0deg); opacity: 1; }
- 100% { -o-transform: translateX(100%) skewX(-30deg); opacity: 0; }
-}
-
-@keyframes lightSpeedOut {
- 0% { transform: translateX(0%) skewX(0deg); opacity: 1; }
- 100% { transform: translateX(100%) skewX(-30deg); opacity: 0; }
-}
-
-.lightSpeedOut {
- -webkit-animation-name: lightSpeedOut;
- -moz-animation-name: lightSpeedOut;
- -o-animation-name: lightSpeedOut;
- animation-name: lightSpeedOut;
-
- -webkit-animation-timing-function: ease-in;
- -moz-animation-timing-function: ease-in;
- -o-animation-timing-function: ease-in;
- animation-timing-function: ease-in;
-}
-
-.animated.lightSpeedOut {
- -webkit-animation-duration: 0.25s;
- -moz-animation-duration: 0.25s;
- -o-animation-duration: 0.25s;
- animation-duration: 0.25s;
-}
-
-/* originally authored by Angelo Rohit - https://github.com/angelorohit */
-
-@-webkit-keyframes wiggle {
- 0% { -webkit-transform: skewX(9deg); }
- 10% { -webkit-transform: skewX(-8deg); }
- 20% { -webkit-transform: skewX(7deg); }
- 30% { -webkit-transform: skewX(-6deg); }
- 40% { -webkit-transform: skewX(5deg); }
- 50% { -webkit-transform: skewX(-4deg); }
- 60% { -webkit-transform: skewX(3deg); }
- 70% { -webkit-transform: skewX(-2deg); }
- 80% { -webkit-transform: skewX(1deg); }
- 90% { -webkit-transform: skewX(0deg); }
- 100% { -webkit-transform: skewX(0deg); }
-}
-
-@-moz-keyframes wiggle {
- 0% { -moz-transform: skewX(9deg); }
- 10% { -moz-transform: skewX(-8deg); }
- 20% { -moz-transform: skewX(7deg); }
- 30% { -moz-transform: skewX(-6deg); }
- 40% { -moz-transform: skewX(5deg); }
- 50% { -moz-transform: skewX(-4deg); }
- 60% { -moz-transform: skewX(3deg); }
- 70% { -moz-transform: skewX(-2deg); }
- 80% { -moz-transform: skewX(1deg); }
- 90% { -moz-transform: skewX(0deg); }
- 100% { -moz-transform: skewX(0deg); }
-}
-
-@-o-keyframes wiggle {
- 0% { -o-transform: skewX(9deg); }
- 10% { -o-transform: skewX(-8deg); }
- 20% { -o-transform: skewX(7deg); }
- 30% { -o-transform: skewX(-6deg); }
- 40% { -o-transform: skewX(5deg); }
- 50% { -o-transform: skewX(-4deg); }
- 60% { -o-transform: skewX(3deg); }
- 70% { -o-transform: skewX(-2deg); }
- 80% { -o-transform: skewX(1deg); }
- 90% { -o-transform: skewX(0deg); }
- 100% { -o-transform: skewX(0deg); }
-}
-
-@keyframes wiggle {
- 0% { transform: skewX(9deg); }
- 10% { transform: skewX(-8deg); }
- 20% { transform: skewX(7deg); }
- 30% { transform: skewX(-6deg); }
- 40% { transform: skewX(5deg); }
- 50% { transform: skewX(-4deg); }
- 60% { transform: skewX(3deg); }
- 70% { transform: skewX(-2deg); }
- 80% { transform: skewX(1deg); }
- 90% { transform: skewX(0deg); }
- 100% { transform: skewX(0deg); }
-}
-
-.wiggle {
- -webkit-animation-name: wiggle;
- -moz-animation-name: wiggle;
- -o-animation-name: wiggle;
- animation-name: wiggle;
-
- -webkit-animation-timing-function: ease-in;
- -moz-animation-timing-function: ease-in;
- -o-animation-timing-function: ease-in;
- animation-timing-function: ease-in;
-}
-
-.animated.wiggle {
- -webkit-animation-duration: 0.75s;
- -moz-animation-duration: 0.75s;
- -o-animation-duration: 0.75s;
- animation-duration: 0.75s;
-}
\ No newline at end of file
diff --git a/app/assets/stylesheets/application.css b/app/assets/stylesheets/application.css
index 6a8411ce..cff4c709 100644
--- a/app/assets/stylesheets/application.css
+++ b/app/assets/stylesheets/application.css
@@ -11,10 +11,8 @@
*= require_self
*= require_tree .
*= require base
- *= require ForceDirected
*= require jquery.mCustomScrollbar
*= require jquery-ui
- *= require animate
*/
/* clear styles */
@@ -1767,14 +1765,6 @@ div.mapInfoStat {
}
/* --- styling the logo button ---*/
-.footer {
- display: block;
- position: fixed;
- bottom: 10px;
- left: 50%;
- margin-left: -55px;
- z-index: 15000;
-}
.home_bg {
display: block;
height: 100%;
diff --git a/app/assets/stylesheets/base.css b/app/assets/stylesheets/base.css
index 37414fce..6173e034 100644
--- a/app/assets/stylesheets/base.css
+++ b/app/assets/stylesheets/base.css
@@ -546,13 +546,14 @@ font-family: 'LatoLight';
.map {
display:inline-block;
- width:226px;
- height:320px;
+ width:220px;
+ height:308px;
+ padding: 16px 0;
color:#FFF;
text-align: left;
overflow: visible;
- background: #FFF;
- border-radius:5px;
+ background: #424242;
+ border-radius:2px;
box-shadow: 6px 6px 8px rgba(0,0,0,0.4);
margin:16px 16px 16px 19px;
}
diff --git a/app/assets/stylesheets/clean.css b/app/assets/stylesheets/clean.css
index d8bd7550..d69db4f2 100644
--- a/app/assets/stylesheets/clean.css
+++ b/app/assets/stylesheets/clean.css
@@ -71,6 +71,11 @@
/* logo */
+
+.footer {
+ z-index: 3;
+}
+
.logo {
color: #6B6B6B;
font-family: "vinyl", sans-serif;
@@ -653,8 +658,7 @@
}
.exploreMapsCenter {
- width: 700px;
- margin: 0 auto;
+ z-index: 3;
}
.exploreMapsCenter a {
@@ -664,9 +668,9 @@
font-family: 'din-medium';
font-size: 14px;
height: 14px;
- padding-top: 16px;
+ padding: 14px;
display: inline-block;
- padding-bottom: 12px;
+ cursor: pointer;
}
.exploreMapsCenter a.active {
text-decoration: none;
@@ -680,6 +684,7 @@
.mapsWrapper {
margin: 100px 60px 0 60px;
display: none;
+ z-index: 1;
}
.explorePage .mapsWrapper {
display:block;
diff --git a/app/assets/stylesheets/synapses.css.scss b/app/assets/stylesheets/synapses.css.scss
deleted file mode 100644
index af453b29..00000000
--- a/app/assets/stylesheets/synapses.css.scss
+++ /dev/null
@@ -1,57 +0,0 @@
-// Place all the styles related to the synapses controller here.
-// They will automatically be included in application.css.
-// You can use Sass (SCSS) here: http://sass-lang.com/
-
-
-.synapse {
- display:block;
- position:relative;
- width:215px;
- height:320px;
- float:left;
- margin: 30px 0 30px 50px;
-}
-
-.synapseTopic1 {
- position:absolute;
- top:0;
-}
-
-.topic1desc {
-display: block;
-width: 190px;
-background: url("bg.png") repeat;
-position: relative;
-margin-left: 25px;
-border-radius: 15px;
-padding: 10px 5px 10px 28px;
-color: #000;
-}
-
-.synapseTopic1 img {
- position:absolute;
- top: 15px;
- z-index: 30;
-}
-
-.synapseTopic2 {
- position:absolute;
- bottom:0;
-}
-
-.synapseTopic2 img {
- position:absolute;
- top:-24px;
- z-index:30;
-}
-
-.topic2desc {
-display: block;
-width: 190px;
-background: url("bg.png") repeat;
-position: relative;
-margin-left: 25px;
-border-radius: 15px;
-padding: 10px 5px 10px 28px;
-color: #000;
-}
\ No newline at end of file
diff --git a/app/controllers/mappings_controller.rb b/app/controllers/mappings_controller.rb
index 566c58a8..97225fa6 100644
--- a/app/controllers/mappings_controller.rb
+++ b/app/controllers/mappings_controller.rb
@@ -4,8 +4,6 @@ class MappingsController < ApplicationController
respond_to :json
- #skip_before_filter :verify_authenticity_token, :only => [:create]
-
# GET /mappings/1.json
def show
@mapping = Mapping.find(params[:id])
diff --git a/app/controllers/synapses_controller.rb b/app/controllers/synapses_controller.rb
index 25a49ffe..f30fa3d5 100644
--- a/app/controllers/synapses_controller.rb
+++ b/app/controllers/synapses_controller.rb
@@ -64,7 +64,7 @@ class SynapsesController < ApplicationController
@synapse.delete if @synapse
respond_to do |format|
- format.json { render :json => "success" }
+ format.json { head :no_content }
end
end
end
diff --git a/app/controllers/users_controller.rb b/app/controllers/users_controller.rb
index e8837510..26085e6b 100644
--- a/app/controllers/users_controller.rb
+++ b/app/controllers/users_controller.rb
@@ -9,16 +9,16 @@ class UsersController < ApplicationController
@user = User.find(params[:id])
render json: @user
- end
+ end
- # GET /user/edit
+ # GET /users/:id/edit
def edit
@user = current_user
respond_with(@user)
end
- # PUT /user
+ # PUT /users/:id
def update
@user = current_user
@user.attributes = params[:user]
diff --git a/app/helpers/topics_helper.rb b/app/helpers/topics_helper.rb
index d89f1c9c..f6587c4c 100644
--- a/app/helpers/topics_helper.rb
+++ b/app/helpers/topics_helper.rb
@@ -22,7 +22,7 @@ module TopicsHelper
return temp
end
-#find all nodes in any given nodes network
+ #find all nodes in any given nodes network
def network(node, array, count)
# recurse starting with a node to find all connected nodes and return an array of topics that constitutes the starting nodes network
@@ -55,102 +55,4 @@ module TopicsHelper
return array
end
end
-
- #return a json object containing all of a users added synapses
- def synapses_as_json(current, synapses)
- Jbuilder.encode do |json|
- @topics = Array.new
-
- synapses.each do |synapse|
- @topics.push(synapse.topic1) if (not @topics.include?(synapse.topic1)) && synapse.topic1.authorize_to_view(current)
- @topics.push(synapse.topic2) if (not @topics.include?(synapse.topic2)) && synapse.topic2.authorize_to_view(current)
- end
-
- json.array!(@topics) do |topic|
- json.adjacencies topic.synapses2.delete_if{|synapse| not @topics.include?(Topic.find_by_id(synapse.node1_id))} do |json, synapse|
- json.nodeTo synapse.node1_id
- json.nodeFrom synapse.node2_id
-
- @synapsedata = Hash.new
- @synapsedata['$desc'] = synapse.desc
- @synapsedata['$showDesc'] = false
- @synapsedata['$category'] = synapse.category
- @synapsedata['$id'] = synapse.id
- @synapsedata['$userid'] = synapse.user.id
- @synapsedata['$username'] = synapse.user.name
- @synapsedata['$direction'] = [synapse.node1_id.to_s(), synapse.node2_id.to_s()]
- @synapsedata['$permission'] = synapse.permission
- json.data @synapsedata
- end
-
- @inmaps = Array.new
- topic.maps.each do |map|
- @inmaps.push(map.id)
- end
-
- @topicdata = Hash.new
- @topicdata['$desc'] = topic.desc
- @topicdata['$link'] = topic.link
- @topicdata['$metacode'] = topic.metacode.name
- @topicdata['$inmaps'] = @inmaps
- @topicdata['$userid'] = topic.user.id
- @topicdata['$username'] = topic.user.name
- @topicdata['$permission'] = topic.permission
- json.data @topicdata
- json.id topic.id
- json.name topic.name
- end
- end
- end
-
- def all_as_json(current, user)
-
- # current is current user
-
- Jbuilder.encode do |json|
- if user.nil?
- @topics = Topic.visibleToUser(current, nil)
- @synapses = Synapse.visibleToUser(current, nil)
- else
- @topics = Topic.visibleToUser(current, user)
- @synapses = Synapse.visibleToUser(current, user)
- end
-
- json.array!(@topics) do |topic|
- json.adjacencies topic.synapses2.delete_if{|synapse| (not @topics.include?(Topic.find_by_id(synapse.node1_id))) || (not @synapses.include?(synapse))} do |json, synapse|
- json.nodeTo synapse.node1_id
- json.nodeFrom synapse.node2_id
-
- @synapsedata = Hash.new
- @synapsedata['$desc'] = synapse.desc
- @synapsedata['$showDesc'] = false
- @synapsedata['$category'] = synapse.category
- @synapsedata['$id'] = synapse.id
- @synapsedata['$userid'] = synapse.user.id
- @synapsedata['$username'] = synapse.user.name
- @synapsedata['$direction'] = [synapse.node1_id.to_s(), synapse.node2_id.to_s()]
- @synapsedata['$permission'] = synapse.permission
- json.data @synapsedata
- end
-
- @inmaps = Array.new
- topic.maps.each do |map|
- @inmaps.push(map.id)
- end
-
- @topicdata = Hash.new
- @topicdata['$desc'] = topic.desc
- @topicdata['$link'] = topic.link
- @topicdata['$metacode'] = topic.metacode.name
- @topicdata['$inmaps'] = @inmaps
- @topicdata['$userid'] = topic.user.id
- @topicdata['$username'] = topic.user.name
- @topicdata['$permission'] = topic.permission
- json.data @topicdata
- json.id topic.id
- json.name topic.name
- end
- end
- end
-
end
diff --git a/app/models/map.rb b/app/models/map.rb
index cc86b6d3..75857c8f 100644
--- a/app/models/map.rb
+++ b/app/models/map.rb
@@ -1,26 +1,26 @@
class Map < ActiveRecord::Base
-belongs_to :user
+ belongs_to :user
-has_many :topicmappings, :class_name => 'Mapping', :conditions => {:category => 'Topic'}
-has_many :synapsemappings, :class_name => 'Mapping', :conditions => {:category => 'Synapse'}
+ has_many :topicmappings, :class_name => 'Mapping', :conditions => {:category => 'Topic'}
+ has_many :synapsemappings, :class_name => 'Mapping', :conditions => {:category => 'Synapse'}
-has_many :topics, :through => :topicmappings
-has_many :synapses, :through => :synapsemappings
+ has_many :topics, :through => :topicmappings
+ has_many :synapses, :through => :synapsemappings
-def mappings
- topicmappings + synapsemappings
-end
-
-def mk_permission
- if self.permission == "commons"
- "co"
- elsif self.permission == "public"
- "pu"
- elsif self.permission == "private"
- "pr"
+ def mappings
+ topicmappings + synapsemappings
+ end
+
+ def mk_permission
+ if self.permission == "commons"
+ "co"
+ elsif self.permission == "public"
+ "pu"
+ elsif self.permission == "private"
+ "pr"
+ end
end
-end
#return an array of the contributors to the map
def contributors
@@ -55,44 +55,30 @@ end
##### PERMISSIONS ######
- scope :visibleToUser, lambda { |current, user|
- if user != nil
- if user != current
- Map.find_all_by_user_id_and_permission(user.id, "commons") | Map.find_all_by_user_id_and_permission(user.id, "public")
- elsif user == current
- Map.find_all_by_user_id_and_permission(user.id, "commons") | Map.find_all_by_user_id_and_permission(user.id, "public") | current.maps.where(:permission => "private")
- end
- elsif (current != nil && user == nil)
- Map.find_all_by_permission("commons") | Map.find_all_by_permission("public") | current.maps.where(:permission => "private")
- elsif (current == nil)
- Map.find_all_by_permission("commons") | Map.find_all_by_permission("public")
- end
- }
-
# returns false if user not allowed to 'show' Topic, Synapse, or Map
def authorize_to_show(user)
- if (self.permission == "private" && self.user != user)
- return false
- end
- return self
+ if (self.permission == "private" && self.user != user)
+ return false
+ end
+ return self
end
# returns false if user not allowed to 'edit' Topic, Synapse, or Map
def authorize_to_edit(user)
- if (self.permission == "private" && self.user != user)
- return false
- elsif (self.permission == "public" && self.user != user)
- return false
- end
- return self
+ if (self.permission == "private" && self.user != user)
+ return false
+ elsif (self.permission == "public" && self.user != user)
+ return false
+ end
+ return self
end
# returns Boolean if user allowed to view Topic, Synapse, or Map
def authorize_to_view(user)
- if (self.permission == "private" && self.user != user)
- return false
- end
- return true
+ if (self.permission == "private" && self.user != user)
+ return false
+ end
+ return true
end
end
diff --git a/app/models/mapping.rb b/app/models/mapping.rb
index 0de78e09..55df39d1 100644
--- a/app/models/mapping.rb
+++ b/app/models/mapping.rb
@@ -1,10 +1,10 @@
class Mapping < ActiveRecord::Base
-belongs_to :topic, :class_name => "Topic", :foreign_key => "topic_id"
-belongs_to :synapse, :class_name => "Synapse", :foreign_key => "synapse_id"
-belongs_to :map, :class_name => "Map", :foreign_key => "map_id"
+ belongs_to :topic, :class_name => "Topic", :foreign_key => "topic_id"
+ belongs_to :synapse, :class_name => "Synapse", :foreign_key => "synapse_id"
+ belongs_to :map, :class_name => "Map", :foreign_key => "map_id"
-belongs_to :user
+ belongs_to :user
def user_name
self.user.name
diff --git a/app/models/synapse.rb b/app/models/synapse.rb
index f7dc58c6..b11f6ad3 100644
--- a/app/models/synapse.rb
+++ b/app/models/synapse.rb
@@ -1,12 +1,12 @@
class Synapse < ActiveRecord::Base
-belongs_to :user
+ belongs_to :user
-belongs_to :topic1, :class_name => "Topic", :foreign_key => "node1_id"
-belongs_to :topic2, :class_name => "Topic", :foreign_key => "node2_id"
+ belongs_to :topic1, :class_name => "Topic", :foreign_key => "node1_id"
+ belongs_to :topic2, :class_name => "Topic", :foreign_key => "node2_id"
-has_many :mappings
-has_many :maps, :through => :mappings
+ has_many :mappings
+ has_many :maps, :through => :mappings
def user_name
self.user.name
@@ -38,83 +38,9 @@ has_many :maps, :through => :mappings
$redis.publish 'maps', msg.to_json
end
end
-
- ##### JSON ######
-
- def self_as_json
- Jbuilder.encode do |json|
- @synapsedata = Hash.new
- @synapsedata['$desc'] = self.desc
- @synapsedata['$showDesc'] = false
- @synapsedata['$category'] = self.category
- @synapsedata['$id'] = self.id
- @synapsedata['$userid'] = self.user.id
- @synapsedata['$username'] = self.user.name
- @synapsedata['$direction'] = [self.node1_id.to_s(), self.node2_id.to_s()]
- @synapsedata['$permission'] = self.permission
- json.data @synapsedata
- end
- end
-
- def selfplusnodes_as_json
- Jbuilder.encode do |json|
- @topics = Array.new
- @topics.push(self.topic1)
- @topics.push(self.topic2)
-
- json.array!(@topics) do |topic|
- json.adjacencies topic.synapses1.delete_if{|synapse| not @topics.include?(Topic.find_by_id(synapse.node2_id))} do |json, synapse|
- json.nodeTo synapse.node2_id
- json.nodeFrom synapse.node1_id
-
- @synapsedata = Hash.new
- @synapsedata['$desc'] = synapse.desc
- @synapsedata['$showDesc'] = false
- @synapsedata['$category'] = synapse.category
- @synapsedata['$id'] = synapse.id
- @synapsedata['$userid'] = synapse.user.id
- @synapsedata['$username'] = synapse.user.name
- @synapsedata['$direction'] = [synapse.node1_id.to_s(), synapse.node2_id.to_s()]
- @synapsedata['$permission'] = synapse.permission
- json.data @synapsedata
- end
-
- @inmaps = Array.new
- topic.maps.each do |map|
- @inmaps.push(map.id)
- end
-
- @topicdata = Hash.new
- @topicdata['$desc'] = topic.desc
- @topicdata['$link'] = topic.link
- @topicdata['$metacode'] = topic.metacode.name
- @topicdata['$inmaps'] = @inmaps
- @topicdata['$userid'] = topic.user.id
- @topicdata['$username'] = topic.user.name
- @topicdata['$permission'] = topic.permission
- json.data @topicdata
- json.id topic.id
- json.name topic.name
- end
- end
- end
##### PERMISSIONS ######
- scope :visibleToUser, lambda { |current, user|
- if user != nil
- if user != current
- Synapse.find_all_by_user_id_and_permission(user.id, "commons") | Synapse.find_all_by_user_id_and_permission(user.id, "public")
- elsif user == current
- Synapse.find_all_by_user_id_and_permission(user.id, "commons") | Synapse.find_all_by_user_id_and_permission(user.id, "public") | current.synapses.where(:permission => "private")
- end
- elsif (current != nil && user == nil)
- Synapse.find_all_by_permission("commons") | Synapse.find_all_by_permission("public") | current.synapses.where(:permission => "private")
- elsif (current == nil)
- Synapse.find_all_by_permission("commons") | Synapse.find_all_by_permission("public")
- end
- }
-
# returns false if user not allowed to 'show' Topic, Synapse, or Map
def authorize_to_show(user)
if (self.permission == "private" && self.user != user)
@@ -140,15 +66,5 @@ has_many :maps, :through => :mappings
end
return true
end
-
- # returns Boolean based on whether user has permissions to edit or not
- def authorize_linkto_edit(user)
- if (self.user == user)
- return true
- elsif (self.permission == "commons")
- return true
- end
- return false
- end
end
diff --git a/app/models/topic.rb b/app/models/topic.rb
index 79183195..e2a44ba4 100644
--- a/app/models/topic.rb
+++ b/app/models/topic.rb
@@ -1,16 +1,15 @@
class Topic < ActiveRecord::Base
+ include TopicsHelper
-include TopicsHelper
+ belongs_to :user
-belongs_to :user
+ has_many :synapses1, :class_name => 'Synapse', :foreign_key => 'node1_id'
+ has_many :synapses2, :class_name => 'Synapse', :foreign_key => 'node2_id'
+ has_many :topics1, :through => :synapses2, :source => :topic1
+ has_many :topics2, :through => :synapses1, :source => :topic2
-has_many :synapses1, :class_name => 'Synapse', :foreign_key => 'node1_id'
-has_many :synapses2, :class_name => 'Synapse', :foreign_key => 'node2_id'
-has_many :topics1, :through => :synapses2, :source => :topic1
-has_many :topics2, :through => :synapses1, :source => :topic2
-
-has_many :mappings
-has_many :maps, :through => :mappings
+ has_many :mappings
+ has_many :maps, :through => :mappings
# This method associates the attribute ":image" with a file attachment
has_attached_file :image
@@ -86,168 +85,17 @@ has_many :maps, :through => :mappings
# has no viewable synapses helper function
def has_viewable_synapses(current)
- result = false
- self.synapses.each do |synapse|
- if synapse.authorize_to_view(current)
- result = true
- end
- end
- return result
- end
-
- ###### JSON ######
-
- def self_as_json
- Jbuilder.encode do |json|
- @inmaps = Array.new
- @mapsString = ""
- self.maps.each_with_index do |map, index|
- @inmaps.push(map.id)
- @mapsString += map.name
- @mapsString += (index+1) == self.maps.count ? "" : ", "
- end
-
- @topicdata = Hash.new
- @topicdata['$desc'] = self.desc
- @topicdata['$link'] = self.link
- @topicdata['$metacode'] = self.metacode.name
- @topicdata['$inmaps'] = @inmaps
- @topicdata['$inmapsString'] = @mapsString
- @topicdata['$synapseCount'] = self.synapses.count
- @topicdata['$userid'] = self.user.id
- @topicdata['$username'] = self.user.name
- @topicdata['$permission'] = self.permission
- @topicdata['$date'] = self.created_at.strftime("%m/%d/%Y")
- json.data @topicdata
- json.id self.id
- json.name self.name
- end
- end
-
- def selfonmap_as_json(mapid)
- Jbuilder.encode do |json|
- @inmaps = Array.new
- @mapsString = ""
- self.maps.each_with_index do |map, index|
- @inmaps.push(map.id)
- @mapsString += map.name
- @mapsString += (index+1) == self.maps.count ? "" : ", "
- end
-
- @topicdata = Hash.new
- @topicdata['$desc'] = self.desc
- @topicdata['$link'] = self.link
- @topicdata['$metacode'] = self.metacode.name
- @topicdata['$inmaps'] = @inmaps
- @topicdata['$inmapsString'] = @mapsString
- @topicdata['$synapseCount'] = self.synapses.count
- @topicdata['$userid'] = self.user.id
- @topicdata['$username'] = self.user.name
- @mapping = Mapping.find_by_topic_id_and_map_id(self.id,mapid)
- @topicdata['$xloc'] = @mapping.xloc
- @topicdata['$yloc'] = @mapping.yloc
- @topicdata['$mappingid'] = @mapping.id
- @topicdata['$permission'] = self.permission
- @topicdata['$date'] = self.created_at.strftime("%m/%d/%Y")
- json.data @topicdata
- json.id self.id
- json.name self.name
- end
- end
-
- #build a json object of everything connected to a specified node
- def network_as_json(current)
- Jbuilder.encode do |json|
- @topics = network(self,nil,1)
-
- if @topics.count > 1
- json.array!(@topics.delete_if{|topic| (not topic.authorize_to_view(current)) || (not topic.has_viewable_synapses(current))}) do |topic|
-
- json.adjacencies topic.synapses1.delete_if{|synapse| (not @topics.include?(synapse.topic2)) || (not synapse.authorize_to_view(current)) || (not synapse.topic2.authorize_to_view(current)) } do |json, synapse|
- json.nodeTo synapse.node2_id
- json.nodeFrom synapse.node1_id
-
- @synapsedata = Hash.new
- @synapsedata['$alpha'] = 0.4
- @synapsedata['$desc'] = synapse.desc
- @synapsedata['$showDesc'] = false
- @synapsedata['$category'] = synapse.category
- @synapsedata['$id'] = synapse.id
- @synapsedata['$userid'] = synapse.user.id
- @synapsedata['$username'] = synapse.user.name
- @synapsedata['$direction'] = [synapse.node1_id.to_s(), synapse.node2_id.to_s()]
- @synapsedata['$permission'] = synapse.permission
- json.data @synapsedata
- end
-
- @inmaps = Array.new
- @mapsString = ""
- topic.maps.each_with_index do |map, index|
- @inmaps.push(map.id)
- @mapsString += map.name
- @mapsString += (index+1) == topic.maps.count ? "" : ", "
- end
-
- @topicdata = Hash.new
- @topicdata['$desc'] = topic.desc
- @topicdata['$link'] = topic.link
- @topicdata['$metacode'] = topic.metacode.name
- @topicdata['$inmaps'] = @inmaps
- @topicdata['$inmapsString'] = @mapsString
- @topicdata['$synapseCount'] = topic.synapses.count
- @topicdata['$userid'] = topic.user.id
- @topicdata['$username'] = topic.user.name
- @topicdata['$permission'] = topic.permission
- @topicdata['$date'] = topic.created_at.strftime("%m/%d/%Y")
- json.data @topicdata
- json.id topic.id
- json.name topic.name
- end
- elsif @topics.count == 1
- json.array!(@topics) do |topic|
- @inmaps = Array.new
- @mapsString = ""
- topic.maps.each_with_index do |map, index|
- @inmaps.push(map.id)
- @mapsString += map.name
- @mapsString += (index+1) == topic.maps.count ? "" : ", "
- end
-
- @topicdata = Hash.new
- @topicdata['$desc'] = topic.desc
- @topicdata['$link'] = topic.link
- @topicdata['$metacode'] = topic.metacode.name
- @topicdata['$inmaps'] = @inmaps
- @topicdata['$inmapsString'] = @mapsString
- @topicdata['$synapseCount'] = topic.synapses.count
- @topicdata['$userid'] = topic.user.id
- @topicdata['$username'] = topic.user.name
- @topicdata['$permission'] = topic.permission
- @topicdata['$date'] = topic.created_at.strftime("%m/%d/%Y")
- json.data @topicdata
- json.id topic.id
- json.name topic.name
- end
- end
- end
+ result = false
+ self.synapses.each do |synapse|
+ if synapse.authorize_to_view(current)
+ result = true
+ end
+ end
+ return result
end
##### PERMISSIONS ######
- scope :visibleToUser, lambda { |current, user|
- if user != nil
- if user != current
- Topic.find_all_by_user_id_and_permission(user.id, "commons") | Topic.find_all_by_user_id_and_permission(user.id, "public")
- elsif user == current
- Topic.find_all_by_user_id_and_permission(user.id, "commons") | Topic.find_all_by_user_id_and_permission(user.id, "public") | current.topics.where(:permission => "private")
- end
- elsif (current != nil && user == nil)
- Topic.find_all_by_permission("commons") | Topic.find_all_by_permission("public") | current.topics.where(:permission => "private")
- elsif (current == nil)
- Topic.find_all_by_permission("commons") | Topic.find_all_by_permission("public")
- end
- }
-
# returns false if user not allowed to 'show' Topic, Synapse, or Map
def authorize_to_show(user)
if (self.permission == "private" && self.user != user)
@@ -273,15 +121,4 @@ has_many :maps, :through => :mappings
end
return true
end
-
- # returns Boolean based on whether user has permissions to edit or not
- def authorize_linkto_edit(user)
- if (self.user == user)
- return true
- elsif (self.permission == "commons")
- return true
- end
- return false
- end
-
end
diff --git a/app/models/user.rb b/app/models/user.rb
index bf2ddd9a..bfdf8fae 100644
--- a/app/models/user.rb
+++ b/app/models/user.rb
@@ -2,10 +2,10 @@ require 'open-uri'
class User < ActiveRecord::Base
-has_many :topics
-has_many :synapses
-has_many :maps
-has_many :mappings
+ has_many :topics
+ has_many :synapses
+ has_many :maps
+ has_many :mappings
before_create :generate_code
@@ -42,7 +42,6 @@ has_many :mappings
def as_json(options={})
{ :id => self.id,
:name => self.name,
- :email => self.email,
:image => self.image.url
}
end
diff --git a/app/views/layouts/_templates.html.erb b/app/views/layouts/_templates.html.erb
index 23d9fd19..a71b1a50 100644
--- a/app/views/layouts/_templates.html.erb
+++ b/app/views/layouts/_templates.html.erb
@@ -7,23 +7,19 @@
diff --git a/app/assets/javascripts/metamaps/Metamaps.Router.js b/app/assets/javascripts/metamaps/Metamaps.Router.js
index 3702400c..0f044dca 100644
--- a/app/assets/javascripts/metamaps/Metamaps.Router.js
+++ b/app/assets/javascripts/metamaps/Metamaps.Router.js
@@ -78,7 +78,7 @@
Metamaps.Loading.loader.show();
setTimeout(function(){
Metamaps.Maps[capitalize].getMaps(); // this will trigger an explore maps render
- }, 1000); // wait 500 milliseconds till the other animations are done to do the fetch
+ }, 300); // wait 300 milliseconds till the other animations are done to do the fetch
}
else {
Metamaps.Views.exploreMaps.render();